#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditContractBorrowDelayModel(object):

    def __init__(self):
        self._category = None
        self._ext = None
        self._out_trans_no = None
        self._service_id = None
        self._subjects_delayed = None

    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        self._ext = value
    @property
    def out_trans_no(self):
        return self._out_trans_no

    @out_trans_no.setter
    def out_trans_no(self, value):
        self._out_trans_no = value
    @property
    def service_id(self):
        return self._service_id

    @service_id.setter
    def service_id(self, value):
        self._service_id = value
    @property
    def subjects_delayed(self):
        return self._subjects_delayed

    @subjects_delayed.setter
    def subjects_delayed(self, value):
        self._subjects_delayed = value


    def to_alipay_dict(self):
        params = dict()
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.ext:
            if hasattr(self.ext, 'to_alipay_dict'):
                params['ext'] = self.ext.to_alipay_dict()
            else:
                params['ext'] = self.ext
        if self.out_trans_no:
            if hasattr(self.out_trans_no, 'to_alipay_dict'):
                params['out_trans_no'] = self.out_trans_no.to_alipay_dict()
            else:
                params['out_trans_no'] = self.out_trans_no
        if self.service_id:
            if hasattr(self.service_id, 'to_alipay_dict'):
                params['service_id'] = self.service_id.to_alipay_dict()
            else:
                params['service_id'] = self.service_id
        if self.subjects_delayed:
            if hasattr(self.subjects_delayed, 'to_alipay_dict'):
                params['subjects_delayed'] = self.subjects_delayed.to_alipay_dict()
            else:
                params['subjects_delayed'] = self.subjects_delayed
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditContractBorrowDelayModel()
        if 'category' in d:
            o.category = d['category']
        if 'ext' in d:
            o.ext = d['ext']
        if 'out_trans_no' in d:
            o.out_trans_no = d['out_trans_no']
        if 'service_id' in d:
            o.service_id = d['service_id']
        if 'subjects_delayed' in d:
            o.subjects_delayed = d['subjects_delayed']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiServindustryPortfolioShopBatchqueryModel(object):

    def __init__(self):
        self._commodity_id = None
        self._page_no = None
        self._page_size = None
        self._shop_id = None

    @property
    def commodity_id(self):
        return self._commodity_id

    @commodity_id.setter
    def commodity_id(self, value):
        self._commodity_id = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.commodity_id:
            if hasattr(self.commodity_id, 'to_alipay_dict'):
                params['commodity_id'] = self.commodity_id.to_alipay_dict()
            else:
                params['commodity_id'] = self.commodity_id
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiServindustryPortfolioShopBatchqueryModel()
        if 'commodity_id' in d:
            o.commodity_id = d['commodity_id']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceDataScenicSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceDataScenicSyncResponse, self).__init__()
        self._desc = None
        self._outer_id = None
        self._scenic_app_id = None
        self._scenic_id = None
        self._status = None
        self._zfb_scenic_id = None

    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def outer_id(self):
        return self._outer_id

    @outer_id.setter
    def outer_id(self, value):
        self._outer_id = value
    @property
    def scenic_app_id(self):
        return self._scenic_app_id

    @scenic_app_id.setter
    def scenic_app_id(self, value):
        self._scenic_app_id = value
    @property
    def scenic_id(self):
        return self._scenic_id

    @scenic_id.setter
    def scenic_id(self, value):
        self._scenic_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def zfb_scenic_id(self):
        return self._zfb_scenic_id

    @zfb_scenic_id.setter
    def zfb_scenic_id(self, value):
        self._zfb_scenic_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceDataScenicSyncResponse, self).parse_response_content(response_content)
        if 'desc' in response:
            self.desc = response['desc']
        if 'outer_id' in response:
            self.outer_id = response['outer_id']
        if 'scenic_app_id' in response:
            self.scenic_app_id = response['scenic_app_id']
        if 'scenic_id' in response:
            self.scenic_id = response['scenic_id']
        if 'status' in response:
            self.status = response['status']
        if 'zfb_scenic_id' in response:
            self.zfb_scenic_id = response['zfb_scenic_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ExSourceRateVO(object):

    def __init__(self):
        self._bid = None
        self._currency_pair = None
        self._currency_unit = None
        self._expiry_time = None
        self._extended_params = None
        self._generate_date = None
        self._generate_time = None
        self._gmt_create = None
        self._gmt_modified = None
        self._guaranteed = None
        self._id = None
        self._inst = None
        self._inst_rate_reference_id = None
        self._is_exception = None
        self._is_flat = None
        self._is_formatted = None
        self._is_valid = None
        self._maturity_date = None
        self._maximum_bid_amount = None
        self._maximum_offer_amount = None
        self._memo = None
        self._mid = None
        self._minimum_bid_amount = None
        self._minimum_offer_amount = None
        self._offer = None
        self._on_off_shore = None
        self._period = None
        self._profile = None
        self._quote_type = None
        self._rate_method = None
        self._rate_source_code = None
        self._rate_type = None
        self._segment_id = None
        self._sp_bid = None
        self._sp_mid = None
        self._sp_offer = None
        self._start_time = None
        self._sub_inst = None
        self._threshold_time = None
        self._valid_time = None
        self._zone_expiry_time = None
        self._zone_generate_time = None
        self._zone_gmt_create = None
        self._zone_gmt_modified = None
        self._zone_start_time = None
        self._zone_threshold_time = None
        self._zone_valid_time = None

    @property
    def bid(self):
        return self._bid

    @bid.setter
    def bid(self, value):
        self._bid = value
    @property
    def currency_pair(self):
        return self._currency_pair

    @currency_pair.setter
    def currency_pair(self, value):
        self._currency_pair = value
    @property
    def currency_unit(self):
        return self._currency_unit

    @currency_unit.setter
    def currency_unit(self, value):
        self._currency_unit = value
    @property
    def expiry_time(self):
        return self._expiry_time

    @expiry_time.setter
    def expiry_time(self, value):
        self._expiry_time = value
    @property
    def extended_params(self):
        return self._extended_params

    @extended_params.setter
    def extended_params(self, value):
        self._extended_params = value
    @property
    def generate_date(self):
        return self._generate_date

    @generate_date.setter
    def generate_date(self, value):
        self._generate_date = value
    @property
    def generate_time(self):
        return self._generate_time

    @generate_time.setter
    def generate_time(self, value):
        self._generate_time = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def guaranteed(self):
        return self._guaranteed

    @guaranteed.setter
    def guaranteed(self, value):
        self._guaranteed = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def inst(self):
        return self._inst

    @inst.setter
    def inst(self, value):
        self._inst = value
    @property
    def inst_rate_reference_id(self):
        return self._inst_rate_reference_id

    @inst_rate_reference_id.setter
    def inst_rate_reference_id(self, value):
        self._inst_rate_reference_id = value
    @property
    def is_exception(self):
        return self._is_exception

    @is_exception.setter
    def is_exception(self, value):
        self._is_exception = value
    @property
    def is_flat(self):
        return self._is_flat

    @is_flat.setter
    def is_flat(self, value):
        self._is_flat = value
    @property
    def is_formatted(self):
        return self._is_formatted

    @is_formatted.setter
    def is_formatted(self, value):
        self._is_formatted = value
    @property
    def is_valid(self):
        return self._is_valid

    @is_valid.setter
    def is_valid(self, value):
        self._is_valid = value
    @property
    def maturity_date(self):
        return self._maturity_date

    @maturity_date.setter
    def maturity_date(self, value):
        self._maturity_date = value
    @property
    def maximum_bid_amount(self):
        return self._maximum_bid_amount

    @maximum_bid_amount.setter
    def maximum_bid_amount(self, value):
        self._maximum_bid_amount = value
    @property
    def maximum_offer_amount(self):
        return self._maximum_offer_amount

    @maximum_offer_amount.setter
    def maximum_offer_amount(self, value):
        self._maximum_offer_amount = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def mid(self):
        return self._mid

    @mid.setter
    def mid(self, value):
        self._mid = value
    @property
    def minimum_bid_amount(self):
        return self._minimum_bid_amount

    @minimum_bid_amount.setter
    def minimum_bid_amount(self, value):
        self._minimum_bid_amount = value
    @property
    def minimum_offer_amount(self):
        return self._minimum_offer_amount

    @minimum_offer_amount.setter
    def minimum_offer_amount(self, value):
        self._minimum_offer_amount = value
    @property
    def offer(self):
        return self._offer

    @offer.setter
    def offer(self, value):
        self._offer = value
    @property
    def on_off_shore(self):
        return self._on_off_shore

    @on_off_shore.setter
    def on_off_shore(self, value):
        self._on_off_shore = value
    @property
    def period(self):
        return self._period

    @period.setter
    def period(self, value):
        self._period = value
    @property
    def profile(self):
        return self._profile

    @profile.setter
    def profile(self, value):
        self._profile = value
    @property
    def quote_type(self):
        return self._quote_type

    @quote_type.setter
    def quote_type(self, value):
        self._quote_type = value
    @property
    def rate_method(self):
        return self._rate_method

    @rate_method.setter
    def rate_method(self, value):
        self._rate_method = value
    @property
    def rate_source_code(self):
        return self._rate_source_code

    @rate_source_code.setter
    def rate_source_code(self, value):
        self._rate_source_code = value
    @property
    def rate_type(self):
        return self._rate_type

    @rate_type.setter
    def rate_type(self, value):
        self._rate_type = value
    @property
    def segment_id(self):
        return self._segment_id

    @segment_id.setter
    def segment_id(self, value):
        self._segment_id = value
    @property
    def sp_bid(self):
        return self._sp_bid

    @sp_bid.setter
    def sp_bid(self, value):
        self._sp_bid = value
    @property
    def sp_mid(self):
        return self._sp_mid

    @sp_mid.setter
    def sp_mid(self, value):
        self._sp_mid = value
    @property
    def sp_offer(self):
        return self._sp_offer

    @sp_offer.setter
    def sp_offer(self, value):
        self._sp_offer = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def sub_inst(self):
        return self._sub_inst

    @sub_inst.setter
    def sub_inst(self, value):
        self._sub_inst = value
    @property
    def threshold_time(self):
        return self._threshold_time

    @threshold_time.setter
    def threshold_time(self, value):
        self._threshold_time = value
    @property
    def valid_time(self):
        return self._valid_time

    @valid_time.setter
    def valid_time(self, value):
        self._valid_time = value
    @property
    def zone_expiry_time(self):
        return self._zone_expiry_time

    @zone_expiry_time.setter
    def zone_expiry_time(self, value):
        self._zone_expiry_time = value
    @property
    def zone_generate_time(self):
        return self._zone_generate_time

    @zone_generate_time.setter
    def zone_generate_time(self, value):
        self._zone_generate_time = value
    @property
    def zone_gmt_create(self):
        return self._zone_gmt_create

    @zone_gmt_create.setter
    def zone_gmt_create(self, value):
        self._zone_gmt_create = value
    @property
    def zone_gmt_modified(self):
        return self._zone_gmt_modified

    @zone_gmt_modified.setter
    def zone_gmt_modified(self, value):
        self._zone_gmt_modified = value
    @property
    def zone_start_time(self):
        return self._zone_start_time

    @zone_start_time.setter
    def zone_start_time(self, value):
        self._zone_start_time = value
    @property
    def zone_threshold_time(self):
        return self._zone_threshold_time

    @zone_threshold_time.setter
    def zone_threshold_time(self, value):
        self._zone_threshold_time = value
    @property
    def zone_valid_time(self):
        return self._zone_valid_time

    @zone_valid_time.setter
    def zone_valid_time(self, value):
        self._zone_valid_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.bid:
            if hasattr(self.bid, 'to_alipay_dict'):
                params['bid'] = self.bid.to_alipay_dict()
            else:
                params['bid'] = self.bid
        if self.currency_pair:
            if hasattr(self.currency_pair, 'to_alipay_dict'):
                params['currency_pair'] = self.currency_pair.to_alipay_dict()
            else:
                params['currency_pair'] = self.currency_pair
        if self.currency_unit:
            if hasattr(self.currency_unit, 'to_alipay_dict'):
                params['currency_unit'] = self.currency_unit.to_alipay_dict()
            else:
                params['currency_unit'] = self.currency_unit
        if self.expiry_time:
            if hasattr(self.expiry_time, 'to_alipay_dict'):
                params['expiry_time'] = self.expiry_time.to_alipay_dict()
            else:
                params['expiry_time'] = self.expiry_time
        if self.extended_params:
            if hasattr(self.extended_params, 'to_alipay_dict'):
                params['extended_params'] = self.extended_params.to_alipay_dict()
            else:
                params['extended_params'] = self.extended_params
        if self.generate_date:
            if hasattr(self.generate_date, 'to_alipay_dict'):
                params['generate_date'] = self.generate_date.to_alipay_dict()
            else:
                params['generate_date'] = self.generate_date
        if self.generate_time:
            if hasattr(self.generate_time, 'to_alipay_dict'):
                params['generate_time'] = self.generate_time.to_alipay_dict()
            else:
                params['generate_time'] = self.generate_time
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.guaranteed:
            if hasattr(self.guaranteed, 'to_alipay_dict'):
                params['guaranteed'] = self.guaranteed.to_alipay_dict()
            else:
                params['guaranteed'] = self.guaranteed
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.inst:
            if hasattr(self.inst, 'to_alipay_dict'):
                params['inst'] = self.inst.to_alipay_dict()
            else:
                params['inst'] = self.inst
        if self.inst_rate_reference_id:
            if hasattr(self.inst_rate_reference_id, 'to_alipay_dict'):
                params['inst_rate_reference_id'] = self.inst_rate_reference_id.to_alipay_dict()
            else:
                params['inst_rate_reference_id'] = self.inst_rate_reference_id
        if self.is_exception:
            if hasattr(self.is_exception, 'to_alipay_dict'):
                params['is_exception'] = self.is_exception.to_alipay_dict()
            else:
                params['is_exception'] = self.is_exception
        if self.is_flat:
            if hasattr(self.is_flat, 'to_alipay_dict'):
                params['is_flat'] = self.is_flat.to_alipay_dict()
            else:
                params['is_flat'] = self.is_flat
        if self.is_formatted:
            if hasattr(self.is_formatted, 'to_alipay_dict'):
                params['is_formatted'] = self.is_formatted.to_alipay_dict()
            else:
                params['is_formatted'] = self.is_formatted
        if self.is_valid:
            if hasattr(self.is_valid, 'to_alipay_dict'):
                params['is_valid'] = self.is_valid.to_alipay_dict()
            else:
                params['is_valid'] = self.is_valid
        if self.maturity_date:
            if hasattr(self.maturity_date, 'to_alipay_dict'):
                params['maturity_date'] = self.maturity_date.to_alipay_dict()
            else:
                params['maturity_date'] = self.maturity_date
        if self.maximum_bid_amount:
            if hasattr(self.maximum_bid_amount, 'to_alipay_dict'):
                params['maximum_bid_amount'] = self.maximum_bid_amount.to_alipay_dict()
            else:
                params['maximum_bid_amount'] = self.maximum_bid_amount
        if self.maximum_offer_amount:
            if hasattr(self.maximum_offer_amount, 'to_alipay_dict'):
                params['maximum_offer_amount'] = self.maximum_offer_amount.to_alipay_dict()
            else:
                params['maximum_offer_amount'] = self.maximum_offer_amount
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.mid:
            if hasattr(self.mid, 'to_alipay_dict'):
                params['mid'] = self.mid.to_alipay_dict()
            else:
                params['mid'] = self.mid
        if self.minimum_bid_amount:
            if hasattr(self.minimum_bid_amount, 'to_alipay_dict'):
                params['minimum_bid_amount'] = self.minimum_bid_amount.to_alipay_dict()
            else:
                params['minimum_bid_amount'] = self.minimum_bid_amount
        if self.minimum_offer_amount:
            if hasattr(self.minimum_offer_amount, 'to_alipay_dict'):
                params['minimum_offer_amount'] = self.minimum_offer_amount.to_alipay_dict()
            else:
                params['minimum_offer_amount'] = self.minimum_offer_amount
        if self.offer:
            if hasattr(self.offer, 'to_alipay_dict'):
                params['offer'] = self.offer.to_alipay_dict()
            else:
                params['offer'] = self.offer
        if self.on_off_shore:
            if hasattr(self.on_off_shore, 'to_alipay_dict'):
                params['on_off_shore'] = self.on_off_shore.to_alipay_dict()
            else:
                params['on_off_shore'] = self.on_off_shore
        if self.period:
            if hasattr(self.period, 'to_alipay_dict'):
                params['period'] = self.period.to_alipay_dict()
            else:
                params['period'] = self.period
        if self.profile:
            if hasattr(self.profile, 'to_alipay_dict'):
                params['profile'] = self.profile.to_alipay_dict()
            else:
                params['profile'] = self.profile
        if self.quote_type:
            if hasattr(self.quote_type, 'to_alipay_dict'):
                params['quote_type'] = self.quote_type.to_alipay_dict()
            else:
                params['quote_type'] = self.quote_type
        if self.rate_method:
            if hasattr(self.rate_method, 'to_alipay_dict'):
                params['rate_method'] = self.rate_method.to_alipay_dict()
            else:
                params['rate_method'] = self.rate_method
        if self.rate_source_code:
            if hasattr(self.rate_source_code, 'to_alipay_dict'):
                params['rate_source_code'] = self.rate_source_code.to_alipay_dict()
            else:
                params['rate_source_code'] = self.rate_source_code
        if self.rate_type:
            if hasattr(self.rate_type, 'to_alipay_dict'):
                params['rate_type'] = self.rate_type.to_alipay_dict()
            else:
                params['rate_type'] = self.rate_type
        if self.segment_id:
            if hasattr(self.segment_id, 'to_alipay_dict'):
                params['segment_id'] = self.segment_id.to_alipay_dict()
            else:
                params['segment_id'] = self.segment_id
        if self.sp_bid:
            if hasattr(self.sp_bid, 'to_alipay_dict'):
                params['sp_bid'] = self.sp_bid.to_alipay_dict()
            else:
                params['sp_bid'] = self.sp_bid
        if self.sp_mid:
            if hasattr(self.sp_mid, 'to_alipay_dict'):
                params['sp_mid'] = self.sp_mid.to_alipay_dict()
            else:
                params['sp_mid'] = self.sp_mid
        if self.sp_offer:
            if hasattr(self.sp_offer, 'to_alipay_dict'):
                params['sp_offer'] = self.sp_offer.to_alipay_dict()
            else:
                params['sp_offer'] = self.sp_offer
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.sub_inst:
            if hasattr(self.sub_inst, 'to_alipay_dict'):
                params['sub_inst'] = self.sub_inst.to_alipay_dict()
            else:
                params['sub_inst'] = self.sub_inst
        if self.threshold_time:
            if hasattr(self.threshold_time, 'to_alipay_dict'):
                params['threshold_time'] = self.threshold_time.to_alipay_dict()
            else:
                params['threshold_time'] = self.threshold_time
        if self.valid_time:
            if hasattr(self.valid_time, 'to_alipay_dict'):
                params['valid_time'] = self.valid_time.to_alipay_dict()
            else:
                params['valid_time'] = self.valid_time
        if self.zone_expiry_time:
            if hasattr(self.zone_expiry_time, 'to_alipay_dict'):
                params['zone_expiry_time'] = self.zone_expiry_time.to_alipay_dict()
            else:
                params['zone_expiry_time'] = self.zone_expiry_time
        if self.zone_generate_time:
            if hasattr(self.zone_generate_time, 'to_alipay_dict'):
                params['zone_generate_time'] = self.zone_generate_time.to_alipay_dict()
            else:
                params['zone_generate_time'] = self.zone_generate_time
        if self.zone_gmt_create:
            if hasattr(self.zone_gmt_create, 'to_alipay_dict'):
                params['zone_gmt_create'] = self.zone_gmt_create.to_alipay_dict()
            else:
                params['zone_gmt_create'] = self.zone_gmt_create
        if self.zone_gmt_modified:
            if hasattr(self.zone_gmt_modified, 'to_alipay_dict'):
                params['zone_gmt_modified'] = self.zone_gmt_modified.to_alipay_dict()
            else:
                params['zone_gmt_modified'] = self.zone_gmt_modified
        if self.zone_start_time:
            if hasattr(self.zone_start_time, 'to_alipay_dict'):
                params['zone_start_time'] = self.zone_start_time.to_alipay_dict()
            else:
                params['zone_start_time'] = self.zone_start_time
        if self.zone_threshold_time:
            if hasattr(self.zone_threshold_time, 'to_alipay_dict'):
                params['zone_threshold_time'] = self.zone_threshold_time.to_alipay_dict()
            else:
                params['zone_threshold_time'] = self.zone_threshold_time
        if self.zone_valid_time:
            if hasattr(self.zone_valid_time, 'to_alipay_dict'):
                params['zone_valid_time'] = self.zone_valid_time.to_alipay_dict()
            else:
                params['zone_valid_time'] = self.zone_valid_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExSourceRateVO()
        if 'bid' in d:
            o.bid = d['bid']
        if 'currency_pair' in d:
            o.currency_pair = d['currency_pair']
        if 'currency_unit' in d:
            o.currency_unit = d['currency_unit']
        if 'expiry_time' in d:
            o.expiry_time = d['expiry_time']
        if 'extended_params' in d:
            o.extended_params = d['extended_params']
        if 'generate_date' in d:
            o.generate_date = d['generate_date']
        if 'generate_time' in d:
            o.generate_time = d['generate_time']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'guaranteed' in d:
            o.guaranteed = d['guaranteed']
        if 'id' in d:
            o.id = d['id']
        if 'inst' in d:
            o.inst = d['inst']
        if 'inst_rate_reference_id' in d:
            o.inst_rate_reference_id = d['inst_rate_reference_id']
        if 'is_exception' in d:
            o.is_exception = d['is_exception']
        if 'is_flat' in d:
            o.is_flat = d['is_flat']
        if 'is_formatted' in d:
            o.is_formatted = d['is_formatted']
        if 'is_valid' in d:
            o.is_valid = d['is_valid']
        if 'maturity_date' in d:
            o.maturity_date = d['maturity_date']
        if 'maximum_bid_amount' in d:
            o.maximum_bid_amount = d['maximum_bid_amount']
        if 'maximum_offer_amount' in d:
            o.maximum_offer_amount = d['maximum_offer_amount']
        if 'memo' in d:
            o.memo = d['memo']
        if 'mid' in d:
            o.mid = d['mid']
        if 'minimum_bid_amount' in d:
            o.minimum_bid_amount = d['minimum_bid_amount']
        if 'minimum_offer_amount' in d:
            o.minimum_offer_amount = d['minimum_offer_amount']
        if 'offer' in d:
            o.offer = d['offer']
        if 'on_off_shore' in d:
            o.on_off_shore = d['on_off_shore']
        if 'period' in d:
            o.period = d['period']
        if 'profile' in d:
            o.profile = d['profile']
        if 'quote_type' in d:
            o.quote_type = d['quote_type']
        if 'rate_method' in d:
            o.rate_method = d['rate_method']
        if 'rate_source_code' in d:
            o.rate_source_code = d['rate_source_code']
        if 'rate_type' in d:
            o.rate_type = d['rate_type']
        if 'segment_id' in d:
            o.segment_id = d['segment_id']
        if 'sp_bid' in d:
            o.sp_bid = d['sp_bid']
        if 'sp_mid' in d:
            o.sp_mid = d['sp_mid']
        if 'sp_offer' in d:
            o.sp_offer = d['sp_offer']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'sub_inst' in d:
            o.sub_inst = d['sub_inst']
        if 'threshold_time' in d:
            o.threshold_time = d['threshold_time']
        if 'valid_time' in d:
            o.valid_time = d['valid_time']
        if 'zone_expiry_time' in d:
            o.zone_expiry_time = d['zone_expiry_time']
        if 'zone_generate_time' in d:
            o.zone_generate_time = d['zone_generate_time']
        if 'zone_gmt_create' in d:
            o.zone_gmt_create = d['zone_gmt_create']
        if 'zone_gmt_modified' in d:
            o.zone_gmt_modified = d['zone_gmt_modified']
        if 'zone_start_time' in d:
            o.zone_start_time = d['zone_start_time']
        if 'zone_threshold_time' in d:
            o.zone_threshold_time = d['zone_threshold_time']
        if 'zone_valid_time' in d:
            o.zone_valid_time = d['zone_valid_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PrizeModel import PrizeModel


class MybankMarketingCampaignPrizeListQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankMarketingCampaignPrizeListQueryResponse, self).__init__()
        self._prize_list = None
        self._total_size = None

    @property
    def prize_list(self):
        return self._prize_list

    @prize_list.setter
    def prize_list(self, value):
        if isinstance(value, list):
            self._prize_list = list()
            for i in value:
                if isinstance(i, PrizeModel):
                    self._prize_list.append(i)
                else:
                    self._prize_list.append(PrizeModel.from_alipay_dict(i))
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(MybankMarketingCampaignPrizeListQueryResponse, self).parse_response_content(response_content)
        if 'prize_list' in response:
            self.prize_list = response['prize_list']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMobileDeviceinfoGetidbytokenResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMobileDeviceinfoGetidbytokenResponse, self).__init__()
        self._apdid = None
        self._operateresult = None
        self._umid = None

    @property
    def apdid(self):
        return self._apdid

    @apdid.setter
    def apdid(self, value):
        self._apdid = value
    @property
    def operateresult(self):
        return self._operateresult

    @operateresult.setter
    def operateresult(self, value):
        self._operateresult = value
    @property
    def umid(self):
        return self._umid

    @umid.setter
    def umid(self, value):
        self._umid = value

    def parse_response_content(self, response_content):
        response = super(AlipayMobileDeviceinfoGetidbytokenResponse, self).parse_response_content(response_content)
        if 'apdid' in response:
            self.apdid = response['apdid']
        if 'operateresult' in response:
            self.operateresult = response['operateresult']
        if 'umid' in response:
            self.umid = response['umid']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradeServiceSignModel(object):

    def __init__(self):
        self._access_channel = None
        self._alipay_user_id = None
        self._biz_type = None
        self._external_logon_id = None
        self._external_user_id = None
        self._sub_biz_type = None

    @property
    def access_channel(self):
        return self._access_channel

    @access_channel.setter
    def access_channel(self, value):
        self._access_channel = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def external_logon_id(self):
        return self._external_logon_id

    @external_logon_id.setter
    def external_logon_id(self, value):
        self._external_logon_id = value
    @property
    def external_user_id(self):
        return self._external_user_id

    @external_user_id.setter
    def external_user_id(self, value):
        self._external_user_id = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.access_channel:
            if hasattr(self.access_channel, 'to_alipay_dict'):
                params['access_channel'] = self.access_channel.to_alipay_dict()
            else:
                params['access_channel'] = self.access_channel
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.external_logon_id:
            if hasattr(self.external_logon_id, 'to_alipay_dict'):
                params['external_logon_id'] = self.external_logon_id.to_alipay_dict()
            else:
                params['external_logon_id'] = self.external_logon_id
        if self.external_user_id:
            if hasattr(self.external_user_id, 'to_alipay_dict'):
                params['external_user_id'] = self.external_user_id.to_alipay_dict()
            else:
                params['external_user_id'] = self.external_user_id
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeServiceSignModel()
        if 'access_channel' in d:
            o.access_channel = d['access_channel']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'external_logon_id' in d:
            o.external_logon_id = d['external_logon_id']
        if 'external_user_id' in d:
            o.external_user_id = d['external_user_id']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InstAllocationQuotaVO import InstAllocationQuotaVO


class AlipayAccountCashpoolRulegroupModifyModel(object):

    def __init__(self):
        self._cash_pool_id = None
        self._config_type = None
        self._inst_allocation_quota_vo_list = None
        self._operator = None
        self._parent_target_water_line = None
        self._rule_group_id = None
        self._rule_group_status = None
        self._trigger_time = None
        self._water_mode = None

    @property
    def cash_pool_id(self):
        return self._cash_pool_id

    @cash_pool_id.setter
    def cash_pool_id(self, value):
        self._cash_pool_id = value
    @property
    def config_type(self):
        return self._config_type

    @config_type.setter
    def config_type(self, value):
        self._config_type = value
    @property
    def inst_allocation_quota_vo_list(self):
        return self._inst_allocation_quota_vo_list

    @inst_allocation_quota_vo_list.setter
    def inst_allocation_quota_vo_list(self, value):
        if isinstance(value, list):
            self._inst_allocation_quota_vo_list = list()
            for i in value:
                if isinstance(i, InstAllocationQuotaVO):
                    self._inst_allocation_quota_vo_list.append(i)
                else:
                    self._inst_allocation_quota_vo_list.append(InstAllocationQuotaVO.from_alipay_dict(i))
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def parent_target_water_line(self):
        return self._parent_target_water_line

    @parent_target_water_line.setter
    def parent_target_water_line(self, value):
        self._parent_target_water_line = value
    @property
    def rule_group_id(self):
        return self._rule_group_id

    @rule_group_id.setter
    def rule_group_id(self, value):
        self._rule_group_id = value
    @property
    def rule_group_status(self):
        return self._rule_group_status

    @rule_group_status.setter
    def rule_group_status(self, value):
        self._rule_group_status = value
    @property
    def trigger_time(self):
        return self._trigger_time

    @trigger_time.setter
    def trigger_time(self, value):
        self._trigger_time = value
    @property
    def water_mode(self):
        return self._water_mode

    @water_mode.setter
    def water_mode(self, value):
        self._water_mode = value


    def to_alipay_dict(self):
        params = dict()
        if self.cash_pool_id:
            if hasattr(self.cash_pool_id, 'to_alipay_dict'):
                params['cash_pool_id'] = self.cash_pool_id.to_alipay_dict()
            else:
                params['cash_pool_id'] = self.cash_pool_id
        if self.config_type:
            if hasattr(self.config_type, 'to_alipay_dict'):
                params['config_type'] = self.config_type.to_alipay_dict()
            else:
                params['config_type'] = self.config_type
        if self.inst_allocation_quota_vo_list:
            if isinstance(self.inst_allocation_quota_vo_list, list):
                for i in range(0, len(self.inst_allocation_quota_vo_list)):
                    element = self.inst_allocation_quota_vo_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.inst_allocation_quota_vo_list[i] = element.to_alipay_dict()
            if hasattr(self.inst_allocation_quota_vo_list, 'to_alipay_dict'):
                params['inst_allocation_quota_vo_list'] = self.inst_allocation_quota_vo_list.to_alipay_dict()
            else:
                params['inst_allocation_quota_vo_list'] = self.inst_allocation_quota_vo_list
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.parent_target_water_line:
            if hasattr(self.parent_target_water_line, 'to_alipay_dict'):
                params['parent_target_water_line'] = self.parent_target_water_line.to_alipay_dict()
            else:
                params['parent_target_water_line'] = self.parent_target_water_line
        if self.rule_group_id:
            if hasattr(self.rule_group_id, 'to_alipay_dict'):
                params['rule_group_id'] = self.rule_group_id.to_alipay_dict()
            else:
                params['rule_group_id'] = self.rule_group_id
        if self.rule_group_status:
            if hasattr(self.rule_group_status, 'to_alipay_dict'):
                params['rule_group_status'] = self.rule_group_status.to_alipay_dict()
            else:
                params['rule_group_status'] = self.rule_group_status
        if self.trigger_time:
            if hasattr(self.trigger_time, 'to_alipay_dict'):
                params['trigger_time'] = self.trigger_time.to_alipay_dict()
            else:
                params['trigger_time'] = self.trigger_time
        if self.water_mode:
            if hasattr(self.water_mode, 'to_alipay_dict'):
                params['water_mode'] = self.water_mode.to_alipay_dict()
            else:
                params['water_mode'] = self.water_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayAccountCashpoolRulegroupModifyModel()
        if 'cash_pool_id' in d:
            o.cash_pool_id = d['cash_pool_id']
        if 'config_type' in d:
            o.config_type = d['config_type']
        if 'inst_allocation_quota_vo_list' in d:
            o.inst_allocation_quota_vo_list = d['inst_allocation_quota_vo_list']
        if 'operator' in d:
            o.operator = d['operator']
        if 'parent_target_water_line' in d:
            o.parent_target_water_line = d['parent_target_water_line']
        if 'rule_group_id' in d:
            o.rule_group_id = d['rule_group_id']
        if 'rule_group_status' in d:
            o.rule_group_status = d['rule_group_status']
        if 'trigger_time' in d:
            o.trigger_time = d['trigger_time']
        if 'water_mode' in d:
            o.water_mode = d['water_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LoanMoneyTypeAmt(object):

    def __init__(self):
        self._fee = None
        self._intr = None
        self._ovd_fine = None
        self._ovd_int = None
        self._ovd_int_pny = None
        self._ovd_prin = None
        self._ovd_prin_pny = None
        self._prin = None

    @property
    def fee(self):
        return self._fee

    @fee.setter
    def fee(self, value):
        self._fee = value
    @property
    def intr(self):
        return self._intr

    @intr.setter
    def intr(self, value):
        self._intr = value
    @property
    def ovd_fine(self):
        return self._ovd_fine

    @ovd_fine.setter
    def ovd_fine(self, value):
        self._ovd_fine = value
    @property
    def ovd_int(self):
        return self._ovd_int

    @ovd_int.setter
    def ovd_int(self, value):
        self._ovd_int = value
    @property
    def ovd_int_pny(self):
        return self._ovd_int_pny

    @ovd_int_pny.setter
    def ovd_int_pny(self, value):
        self._ovd_int_pny = value
    @property
    def ovd_prin(self):
        return self._ovd_prin

    @ovd_prin.setter
    def ovd_prin(self, value):
        self._ovd_prin = value
    @property
    def ovd_prin_pny(self):
        return self._ovd_prin_pny

    @ovd_prin_pny.setter
    def ovd_prin_pny(self, value):
        self._ovd_prin_pny = value
    @property
    def prin(self):
        return self._prin

    @prin.setter
    def prin(self, value):
        self._prin = value


    def to_alipay_dict(self):
        params = dict()
        if self.fee:
            if hasattr(self.fee, 'to_alipay_dict'):
                params['fee'] = self.fee.to_alipay_dict()
            else:
                params['fee'] = self.fee
        if self.intr:
            if hasattr(self.intr, 'to_alipay_dict'):
                params['intr'] = self.intr.to_alipay_dict()
            else:
                params['intr'] = self.intr
        if self.ovd_fine:
            if hasattr(self.ovd_fine, 'to_alipay_dict'):
                params['ovd_fine'] = self.ovd_fine.to_alipay_dict()
            else:
                params['ovd_fine'] = self.ovd_fine
        if self.ovd_int:
            if hasattr(self.ovd_int, 'to_alipay_dict'):
                params['ovd_int'] = self.ovd_int.to_alipay_dict()
            else:
                params['ovd_int'] = self.ovd_int
        if self.ovd_int_pny:
            if hasattr(self.ovd_int_pny, 'to_alipay_dict'):
                params['ovd_int_pny'] = self.ovd_int_pny.to_alipay_dict()
            else:
                params['ovd_int_pny'] = self.ovd_int_pny
        if self.ovd_prin:
            if hasattr(self.ovd_prin, 'to_alipay_dict'):
                params['ovd_prin'] = self.ovd_prin.to_alipay_dict()
            else:
                params['ovd_prin'] = self.ovd_prin
        if self.ovd_prin_pny:
            if hasattr(self.ovd_prin_pny, 'to_alipay_dict'):
                params['ovd_prin_pny'] = self.ovd_prin_pny.to_alipay_dict()
            else:
                params['ovd_prin_pny'] = self.ovd_prin_pny
        if self.prin:
            if hasattr(self.prin, 'to_alipay_dict'):
                params['prin'] = self.prin.to_alipay_dict()
            else:
                params['prin'] = self.prin
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LoanMoneyTypeAmt()
        if 'fee' in d:
            o.fee = d['fee']
        if 'intr' in d:
            o.intr = d['intr']
        if 'ovd_fine' in d:
            o.ovd_fine = d['ovd_fine']
        if 'ovd_int' in d:
            o.ovd_int = d['ovd_int']
        if 'ovd_int_pny' in d:
            o.ovd_int_pny = d['ovd_int_pny']
        if 'ovd_prin' in d:
            o.ovd_prin = d['ovd_prin']
        if 'ovd_prin_pny' in d:
            o.ovd_prin_pny = d['ovd_prin_pny']
        if 'prin' in d:
            o.prin = d['prin']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingToolPointsUpdateModel(object):

    def __init__(self):
        self._activity_account = None
        self._biz_no = None
        self._ext_info = None
        self._memo = None
        self._req_id = None
        self._shop_id = None
        self._trans_amount = None
        self._trans_type = None
        self._user_id = None

    @property
    def activity_account(self):
        return self._activity_account

    @activity_account.setter
    def activity_account(self, value):
        self._activity_account = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def req_id(self):
        return self._req_id

    @req_id.setter
    def req_id(self, value):
        self._req_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def trans_amount(self):
        return self._trans_amount

    @trans_amount.setter
    def trans_amount(self, value):
        self._trans_amount = value
    @property
    def trans_type(self):
        return self._trans_type

    @trans_type.setter
    def trans_type(self, value):
        self._trans_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_account:
            if hasattr(self.activity_account, 'to_alipay_dict'):
                params['activity_account'] = self.activity_account.to_alipay_dict()
            else:
                params['activity_account'] = self.activity_account
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.req_id:
            if hasattr(self.req_id, 'to_alipay_dict'):
                params['req_id'] = self.req_id.to_alipay_dict()
            else:
                params['req_id'] = self.req_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.trans_amount:
            if hasattr(self.trans_amount, 'to_alipay_dict'):
                params['trans_amount'] = self.trans_amount.to_alipay_dict()
            else:
                params['trans_amount'] = self.trans_amount
        if self.trans_type:
            if hasattr(self.trans_type, 'to_alipay_dict'):
                params['trans_type'] = self.trans_type.to_alipay_dict()
            else:
                params['trans_type'] = self.trans_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingToolPointsUpdateModel()
        if 'activity_account' in d:
            o.activity_account = d['activity_account']
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'memo' in d:
            o.memo = d['memo']
        if 'req_id' in d:
            o.req_id = d['req_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'trans_amount' in d:
            o.trans_amount = d['trans_amount']
        if 'trans_type' in d:
            o.trans_type = d['trans_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeviceResultInfo(object):

    def __init__(self):
        self._device_id = None
        self._device_label = None

    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def device_label(self):
        return self._device_label

    @device_label.setter
    def device_label(self, value):
        self._device_label = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.device_label:
            if hasattr(self.device_label, 'to_alipay_dict'):
                params['device_label'] = self.device_label.to_alipay_dict()
            else:
                params['device_label'] = self.device_label
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeviceResultInfo()
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'device_label' in d:
            o.device_label = d['device_label']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ItapResponsePayload import ItapResponsePayload


class AlipayMsaasItapDataSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMsaasItapDataSyncResponse, self).__init__()
        self._payload = None
        self._request_id = None

    @property
    def payload(self):
        return self._payload

    @payload.setter
    def payload(self, value):
        if isinstance(value, list):
            self._payload = list()
            for i in value:
                if isinstance(i, ItapResponsePayload):
                    self._payload.append(i)
                else:
                    self._payload.append(ItapResponsePayload.from_alipay_dict(i))
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayMsaasItapDataSyncResponse, self).parse_response_content(response_content)
        if 'payload' in response:
            self.payload = response['payload']
        if 'request_id' in response:
            self.request_id = response['request_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AvailablePeriodInfo import AvailablePeriodInfo
from alipay.aop.api.domain.BuyerNotesInfo import BuyerNotesInfo
from alipay.aop.api.domain.ItemDishInfo import ItemDishInfo
from alipay.aop.api.domain.ItemPackageInfo import ItemPackageInfo
from alipay.aop.api.domain.IntroductionInfo import IntroductionInfo
from alipay.aop.api.domain.UnavailablePeriodInfo import UnavailablePeriodInfo


class KoubeiCateringItemModifyModel(object):

    def __init__(self):
        self._auth_code = None
        self._available_periods = None
        self._buyer_notes = None
        self._category_id = None
        self._cover = None
        self._external_code_inventory_id = None
        self._external_code_template_id = None
        self._gmt_end = None
        self._gmt_start = None
        self._inventory = None
        self._item_dishes = None
        self._item_display_channel = None
        self._item_id = None
        self._item_packages = None
        self._latest_notice = None
        self._memo = None
        self._merchant_introduction = None
        self._operator_type = None
        self._original_price = None
        self._package_notes = None
        self._picture_details = None
        self._price = None
        self._request_id = None
        self._shop_ids = None
        self._sku_id = None
        self._subject = None
        self._taobao_cover_image = None
        self._ticket_display_mode = None
        self._unavailable_periods = None
        self._validity_period = None
        self._weight = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def available_periods(self):
        return self._available_periods

    @available_periods.setter
    def available_periods(self, value):
        if isinstance(value, list):
            self._available_periods = list()
            for i in value:
                if isinstance(i, AvailablePeriodInfo):
                    self._available_periods.append(i)
                else:
                    self._available_periods.append(AvailablePeriodInfo.from_alipay_dict(i))
    @property
    def buyer_notes(self):
        return self._buyer_notes

    @buyer_notes.setter
    def buyer_notes(self, value):
        if isinstance(value, BuyerNotesInfo):
            self._buyer_notes = value
        else:
            self._buyer_notes = BuyerNotesInfo.from_alipay_dict(value)
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def cover(self):
        return self._cover

    @cover.setter
    def cover(self, value):
        self._cover = value
    @property
    def external_code_inventory_id(self):
        return self._external_code_inventory_id

    @external_code_inventory_id.setter
    def external_code_inventory_id(self, value):
        self._external_code_inventory_id = value
    @property
    def external_code_template_id(self):
        return self._external_code_template_id

    @external_code_template_id.setter
    def external_code_template_id(self, value):
        self._external_code_template_id = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_start(self):
        return self._gmt_start

    @gmt_start.setter
    def gmt_start(self, value):
        self._gmt_start = value
    @property
    def inventory(self):
        return self._inventory

    @inventory.setter
    def inventory(self, value):
        self._inventory = value
    @property
    def item_dishes(self):
        return self._item_dishes

    @item_dishes.setter
    def item_dishes(self, value):
        if isinstance(value, list):
            self._item_dishes = list()
            for i in value:
                if isinstance(i, ItemDishInfo):
                    self._item_dishes.append(i)
                else:
                    self._item_dishes.append(ItemDishInfo.from_alipay_dict(i))
    @property
    def item_display_channel(self):
        return self._item_display_channel

    @item_display_channel.setter
    def item_display_channel(self, value):
        self._item_display_channel = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_packages(self):
        return self._item_packages

    @item_packages.setter
    def item_packages(self, value):
        if isinstance(value, list):
            self._item_packages = list()
            for i in value:
                if isinstance(i, ItemPackageInfo):
                    self._item_packages.append(i)
                else:
                    self._item_packages.append(ItemPackageInfo.from_alipay_dict(i))
    @property
    def latest_notice(self):
        return self._latest_notice

    @latest_notice.setter
    def latest_notice(self, value):
        self._latest_notice = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def merchant_introduction(self):
        return self._merchant_introduction

    @merchant_introduction.setter
    def merchant_introduction(self, value):
        if isinstance(value, IntroductionInfo):
            self._merchant_introduction = value
        else:
            self._merchant_introduction = IntroductionInfo.from_alipay_dict(value)
    @property
    def operator_type(self):
        return self._operator_type

    @operator_type.setter
    def operator_type(self, value):
        self._operator_type = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def package_notes(self):
        return self._package_notes

    @package_notes.setter
    def package_notes(self, value):
        if isinstance(value, list):
            self._package_notes = list()
            for i in value:
                self._package_notes.append(i)
    @property
    def picture_details(self):
        return self._picture_details

    @picture_details.setter
    def picture_details(self, value):
        if isinstance(value, list):
            self._picture_details = list()
            for i in value:
                self._picture_details.append(i)
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        if isinstance(value, list):
            self._shop_ids = list()
            for i in value:
                self._shop_ids.append(i)
    @property
    def sku_id(self):
        return self._sku_id

    @sku_id.setter
    def sku_id(self, value):
        self._sku_id = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def taobao_cover_image(self):
        return self._taobao_cover_image

    @taobao_cover_image.setter
    def taobao_cover_image(self, value):
        self._taobao_cover_image = value
    @property
    def ticket_display_mode(self):
        return self._ticket_display_mode

    @ticket_display_mode.setter
    def ticket_display_mode(self, value):
        self._ticket_display_mode = value
    @property
    def unavailable_periods(self):
        return self._unavailable_periods

    @unavailable_periods.setter
    def unavailable_periods(self, value):
        if isinstance(value, list):
            self._unavailable_periods = list()
            for i in value:
                if isinstance(i, UnavailablePeriodInfo):
                    self._unavailable_periods.append(i)
                else:
                    self._unavailable_periods.append(UnavailablePeriodInfo.from_alipay_dict(i))
    @property
    def validity_period(self):
        return self._validity_period

    @validity_period.setter
    def validity_period(self, value):
        self._validity_period = value
    @property
    def weight(self):
        return self._weight

    @weight.setter
    def weight(self, value):
        self._weight = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.available_periods:
            if isinstance(self.available_periods, list):
                for i in range(0, len(self.available_periods)):
                    element = self.available_periods[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.available_periods[i] = element.to_alipay_dict()
            if hasattr(self.available_periods, 'to_alipay_dict'):
                params['available_periods'] = self.available_periods.to_alipay_dict()
            else:
                params['available_periods'] = self.available_periods
        if self.buyer_notes:
            if hasattr(self.buyer_notes, 'to_alipay_dict'):
                params['buyer_notes'] = self.buyer_notes.to_alipay_dict()
            else:
                params['buyer_notes'] = self.buyer_notes
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.cover:
            if hasattr(self.cover, 'to_alipay_dict'):
                params['cover'] = self.cover.to_alipay_dict()
            else:
                params['cover'] = self.cover
        if self.external_code_inventory_id:
            if hasattr(self.external_code_inventory_id, 'to_alipay_dict'):
                params['external_code_inventory_id'] = self.external_code_inventory_id.to_alipay_dict()
            else:
                params['external_code_inventory_id'] = self.external_code_inventory_id
        if self.external_code_template_id:
            if hasattr(self.external_code_template_id, 'to_alipay_dict'):
                params['external_code_template_id'] = self.external_code_template_id.to_alipay_dict()
            else:
                params['external_code_template_id'] = self.external_code_template_id
        if self.gmt_end:
            if hasattr(self.gmt_end, 'to_alipay_dict'):
                params['gmt_end'] = self.gmt_end.to_alipay_dict()
            else:
                params['gmt_end'] = self.gmt_end
        if self.gmt_start:
            if hasattr(self.gmt_start, 'to_alipay_dict'):
                params['gmt_start'] = self.gmt_start.to_alipay_dict()
            else:
                params['gmt_start'] = self.gmt_start
        if self.inventory:
            if hasattr(self.inventory, 'to_alipay_dict'):
                params['inventory'] = self.inventory.to_alipay_dict()
            else:
                params['inventory'] = self.inventory
        if self.item_dishes:
            if isinstance(self.item_dishes, list):
                for i in range(0, len(self.item_dishes)):
                    element = self.item_dishes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_dishes[i] = element.to_alipay_dict()
            if hasattr(self.item_dishes, 'to_alipay_dict'):
                params['item_dishes'] = self.item_dishes.to_alipay_dict()
            else:
                params['item_dishes'] = self.item_dishes
        if self.item_display_channel:
            if hasattr(self.item_display_channel, 'to_alipay_dict'):
                params['item_display_channel'] = self.item_display_channel.to_alipay_dict()
            else:
                params['item_display_channel'] = self.item_display_channel
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_packages:
            if isinstance(self.item_packages, list):
                for i in range(0, len(self.item_packages)):
                    element = self.item_packages[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_packages[i] = element.to_alipay_dict()
            if hasattr(self.item_packages, 'to_alipay_dict'):
                params['item_packages'] = self.item_packages.to_alipay_dict()
            else:
                params['item_packages'] = self.item_packages
        if self.latest_notice:
            if hasattr(self.latest_notice, 'to_alipay_dict'):
                params['latest_notice'] = self.latest_notice.to_alipay_dict()
            else:
                params['latest_notice'] = self.latest_notice
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.merchant_introduction:
            if hasattr(self.merchant_introduction, 'to_alipay_dict'):
                params['merchant_introduction'] = self.merchant_introduction.to_alipay_dict()
            else:
                params['merchant_introduction'] = self.merchant_introduction
        if self.operator_type:
            if hasattr(self.operator_type, 'to_alipay_dict'):
                params['operator_type'] = self.operator_type.to_alipay_dict()
            else:
                params['operator_type'] = self.operator_type
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.package_notes:
            if isinstance(self.package_notes, list):
                for i in range(0, len(self.package_notes)):
                    element = self.package_notes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.package_notes[i] = element.to_alipay_dict()
            if hasattr(self.package_notes, 'to_alipay_dict'):
                params['package_notes'] = self.package_notes.to_alipay_dict()
            else:
                params['package_notes'] = self.package_notes
        if self.picture_details:
            if isinstance(self.picture_details, list):
                for i in range(0, len(self.picture_details)):
                    element = self.picture_details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.picture_details[i] = element.to_alipay_dict()
            if hasattr(self.picture_details, 'to_alipay_dict'):
                params['picture_details'] = self.picture_details.to_alipay_dict()
            else:
                params['picture_details'] = self.picture_details
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.shop_ids:
            if isinstance(self.shop_ids, list):
                for i in range(0, len(self.shop_ids)):
                    element = self.shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.shop_ids, 'to_alipay_dict'):
                params['shop_ids'] = self.shop_ids.to_alipay_dict()
            else:
                params['shop_ids'] = self.shop_ids
        if self.sku_id:
            if hasattr(self.sku_id, 'to_alipay_dict'):
                params['sku_id'] = self.sku_id.to_alipay_dict()
            else:
                params['sku_id'] = self.sku_id
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.taobao_cover_image:
            if hasattr(self.taobao_cover_image, 'to_alipay_dict'):
                params['taobao_cover_image'] = self.taobao_cover_image.to_alipay_dict()
            else:
                params['taobao_cover_image'] = self.taobao_cover_image
        if self.ticket_display_mode:
            if hasattr(self.ticket_display_mode, 'to_alipay_dict'):
                params['ticket_display_mode'] = self.ticket_display_mode.to_alipay_dict()
            else:
                params['ticket_display_mode'] = self.ticket_display_mode
        if self.unavailable_periods:
            if isinstance(self.unavailable_periods, list):
                for i in range(0, len(self.unavailable_periods)):
                    element = self.unavailable_periods[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.unavailable_periods[i] = element.to_alipay_dict()
            if hasattr(self.unavailable_periods, 'to_alipay_dict'):
                params['unavailable_periods'] = self.unavailable_periods.to_alipay_dict()
            else:
                params['unavailable_periods'] = self.unavailable_periods
        if self.validity_period:
            if hasattr(self.validity_period, 'to_alipay_dict'):
                params['validity_period'] = self.validity_period.to_alipay_dict()
            else:
                params['validity_period'] = self.validity_period
        if self.weight:
            if hasattr(self.weight, 'to_alipay_dict'):
                params['weight'] = self.weight.to_alipay_dict()
            else:
                params['weight'] = self.weight
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringItemModifyModel()
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'available_periods' in d:
            o.available_periods = d['available_periods']
        if 'buyer_notes' in d:
            o.buyer_notes = d['buyer_notes']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'cover' in d:
            o.cover = d['cover']
        if 'external_code_inventory_id' in d:
            o.external_code_inventory_id = d['external_code_inventory_id']
        if 'external_code_template_id' in d:
            o.external_code_template_id = d['external_code_template_id']
        if 'gmt_end' in d:
            o.gmt_end = d['gmt_end']
        if 'gmt_start' in d:
            o.gmt_start = d['gmt_start']
        if 'inventory' in d:
            o.inventory = d['inventory']
        if 'item_dishes' in d:
            o.item_dishes = d['item_dishes']
        if 'item_display_channel' in d:
            o.item_display_channel = d['item_display_channel']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_packages' in d:
            o.item_packages = d['item_packages']
        if 'latest_notice' in d:
            o.latest_notice = d['latest_notice']
        if 'memo' in d:
            o.memo = d['memo']
        if 'merchant_introduction' in d:
            o.merchant_introduction = d['merchant_introduction']
        if 'operator_type' in d:
            o.operator_type = d['operator_type']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'package_notes' in d:
            o.package_notes = d['package_notes']
        if 'picture_details' in d:
            o.picture_details = d['picture_details']
        if 'price' in d:
            o.price = d['price']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'shop_ids' in d:
            o.shop_ids = d['shop_ids']
        if 'sku_id' in d:
            o.sku_id = d['sku_id']
        if 'subject' in d:
            o.subject = d['subject']
        if 'taobao_cover_image' in d:
            o.taobao_cover_image = d['taobao_cover_image']
        if 'ticket_display_mode' in d:
            o.ticket_display_mode = d['ticket_display_mode']
        if 'unavailable_periods' in d:
            o.unavailable_periods = d['unavailable_periods']
        if 'validity_period' in d:
            o.validity_period = d['validity_period']
        if 'weight' in d:
            o.weight = d['weight']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniBaseinfoMultiQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniBaseinfoMultiQueryResponse, self).__init__()
        self._account_type = None
        self._app_desc = None
        self._app_english_name = None
        self._app_logo = None
        self._app_name = None
        self._app_slogan = None
        self._area = None
        self._business_license_no = None
        self._business_name = None
        self._category_names = None
        self._contact_email = None
        self._contact_mobile = None
        self._contact_name = None
        self._pid = None
        self._service_email = None
        self._service_phone = None

    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def app_desc(self):
        return self._app_desc

    @app_desc.setter
    def app_desc(self, value):
        self._app_desc = value
    @property
    def app_english_name(self):
        return self._app_english_name

    @app_english_name.setter
    def app_english_name(self, value):
        self._app_english_name = value
    @property
    def app_logo(self):
        return self._app_logo

    @app_logo.setter
    def app_logo(self, value):
        self._app_logo = value
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_slogan(self):
        return self._app_slogan

    @app_slogan.setter
    def app_slogan(self, value):
        self._app_slogan = value
    @property
    def area(self):
        return self._area

    @area.setter
    def area(self, value):
        self._area = value
    @property
    def business_license_no(self):
        return self._business_license_no

    @business_license_no.setter
    def business_license_no(self, value):
        self._business_license_no = value
    @property
    def business_name(self):
        return self._business_name

    @business_name.setter
    def business_name(self, value):
        self._business_name = value
    @property
    def category_names(self):
        return self._category_names

    @category_names.setter
    def category_names(self, value):
        self._category_names = value
    @property
    def contact_email(self):
        return self._contact_email

    @contact_email.setter
    def contact_email(self, value):
        self._contact_email = value
    @property
    def contact_mobile(self):
        return self._contact_mobile

    @contact_mobile.setter
    def contact_mobile(self, value):
        self._contact_mobile = value
    @property
    def contact_name(self):
        return self._contact_name

    @contact_name.setter
    def contact_name(self, value):
        self._contact_name = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def service_email(self):
        return self._service_email

    @service_email.setter
    def service_email(self, value):
        self._service_email = value
    @property
    def service_phone(self):
        return self._service_phone

    @service_phone.setter
    def service_phone(self, value):
        self._service_phone = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniBaseinfoMultiQueryResponse, self).parse_response_content(response_content)
        if 'account_type' in response:
            self.account_type = response['account_type']
        if 'app_desc' in response:
            self.app_desc = response['app_desc']
        if 'app_english_name' in response:
            self.app_english_name = response['app_english_name']
        if 'app_logo' in response:
            self.app_logo = response['app_logo']
        if 'app_name' in response:
            self.app_name = response['app_name']
        if 'app_slogan' in response:
            self.app_slogan = response['app_slogan']
        if 'area' in response:
            self.area = response['area']
        if 'business_license_no' in response:
            self.business_license_no = response['business_license_no']
        if 'business_name' in response:
            self.business_name = response['business_name']
        if 'category_names' in response:
            self.category_names = response['category_names']
        if 'contact_email' in response:
            self.contact_email = response['contact_email']
        if 'contact_mobile' in response:
            self.contact_mobile = response['contact_mobile']
        if 'contact_name' in response:
            self.contact_name = response['contact_name']
        if 'pid' in response:
            self.pid = response['pid']
        if 'service_email' in response:
            self.service_email = response['service_email']
        if 'service_phone' in response:
            self.service_phone = response['service_phone']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOverseasTravelPromotionGetModel(object):

    def __init__(self):
        self._biz_area_codes = None
        self._ch_info = None
        self._city_codes = None
        self._country_codes = None
        self._latitude = None
        self._lbs_reverse_level = None
        self._longitude = None
        self._page_no = None
        self._page_size = None
        self._radius = None
        self._scene_code = None
        self._shop_id = None
        self._top_promotion_ids = None
        self._unique_id = None
        self._user_id = None
        self._user_id_type = None

    @property
    def biz_area_codes(self):
        return self._biz_area_codes

    @biz_area_codes.setter
    def biz_area_codes(self, value):
        if isinstance(value, list):
            self._biz_area_codes = list()
            for i in value:
                self._biz_area_codes.append(i)
    @property
    def ch_info(self):
        return self._ch_info

    @ch_info.setter
    def ch_info(self, value):
        self._ch_info = value
    @property
    def city_codes(self):
        return self._city_codes

    @city_codes.setter
    def city_codes(self, value):
        if isinstance(value, list):
            self._city_codes = list()
            for i in value:
                self._city_codes.append(i)
    @property
    def country_codes(self):
        return self._country_codes

    @country_codes.setter
    def country_codes(self, value):
        if isinstance(value, list):
            self._country_codes = list()
            for i in value:
                self._country_codes.append(i)
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def lbs_reverse_level(self):
        return self._lbs_reverse_level

    @lbs_reverse_level.setter
    def lbs_reverse_level(self, value):
        self._lbs_reverse_level = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def radius(self):
        return self._radius

    @radius.setter
    def radius(self, value):
        self._radius = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def top_promotion_ids(self):
        return self._top_promotion_ids

    @top_promotion_ids.setter
    def top_promotion_ids(self, value):
        if isinstance(value, list):
            self._top_promotion_ids = list()
            for i in value:
                self._top_promotion_ids.append(i)
    @property
    def unique_id(self):
        return self._unique_id

    @unique_id.setter
    def unique_id(self, value):
        self._unique_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_id_type(self):
        return self._user_id_type

    @user_id_type.setter
    def user_id_type(self, value):
        self._user_id_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_area_codes:
            if isinstance(self.biz_area_codes, list):
                for i in range(0, len(self.biz_area_codes)):
                    element = self.biz_area_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.biz_area_codes[i] = element.to_alipay_dict()
            if hasattr(self.biz_area_codes, 'to_alipay_dict'):
                params['biz_area_codes'] = self.biz_area_codes.to_alipay_dict()
            else:
                params['biz_area_codes'] = self.biz_area_codes
        if self.ch_info:
            if hasattr(self.ch_info, 'to_alipay_dict'):
                params['ch_info'] = self.ch_info.to_alipay_dict()
            else:
                params['ch_info'] = self.ch_info
        if self.city_codes:
            if isinstance(self.city_codes, list):
                for i in range(0, len(self.city_codes)):
                    element = self.city_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.city_codes[i] = element.to_alipay_dict()
            if hasattr(self.city_codes, 'to_alipay_dict'):
                params['city_codes'] = self.city_codes.to_alipay_dict()
            else:
                params['city_codes'] = self.city_codes
        if self.country_codes:
            if isinstance(self.country_codes, list):
                for i in range(0, len(self.country_codes)):
                    element = self.country_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.country_codes[i] = element.to_alipay_dict()
            if hasattr(self.country_codes, 'to_alipay_dict'):
                params['country_codes'] = self.country_codes.to_alipay_dict()
            else:
                params['country_codes'] = self.country_codes
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.lbs_reverse_level:
            if hasattr(self.lbs_reverse_level, 'to_alipay_dict'):
                params['lbs_reverse_level'] = self.lbs_reverse_level.to_alipay_dict()
            else:
                params['lbs_reverse_level'] = self.lbs_reverse_level
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.radius:
            if hasattr(self.radius, 'to_alipay_dict'):
                params['radius'] = self.radius.to_alipay_dict()
            else:
                params['radius'] = self.radius
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.top_promotion_ids:
            if isinstance(self.top_promotion_ids, list):
                for i in range(0, len(self.top_promotion_ids)):
                    element = self.top_promotion_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.top_promotion_ids[i] = element.to_alipay_dict()
            if hasattr(self.top_promotion_ids, 'to_alipay_dict'):
                params['top_promotion_ids'] = self.top_promotion_ids.to_alipay_dict()
            else:
                params['top_promotion_ids'] = self.top_promotion_ids
        if self.unique_id:
            if hasattr(self.unique_id, 'to_alipay_dict'):
                params['unique_id'] = self.unique_id.to_alipay_dict()
            else:
                params['unique_id'] = self.unique_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_id_type:
            if hasattr(self.user_id_type, 'to_alipay_dict'):
                params['user_id_type'] = self.user_id_type.to_alipay_dict()
            else:
                params['user_id_type'] = self.user_id_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasTravelPromotionGetModel()
        if 'biz_area_codes' in d:
            o.biz_area_codes = d['biz_area_codes']
        if 'ch_info' in d:
            o.ch_info = d['ch_info']
        if 'city_codes' in d:
            o.city_codes = d['city_codes']
        if 'country_codes' in d:
            o.country_codes = d['country_codes']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'lbs_reverse_level' in d:
            o.lbs_reverse_level = d['lbs_reverse_level']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'radius' in d:
            o.radius = d['radius']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'top_promotion_ids' in d:
            o.top_promotion_ids = d['top_promotion_ids']
        if 'unique_id' in d:
            o.unique_id = d['unique_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_id_type' in d:
            o.user_id_type = d['user_id_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AccessParams import AccessParams


class AlipayOpenAppTestTestCreateModel(object):

    def __init__(self):
        self._address = None
        self._latitude = None
        self._longitude = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        if isinstance(value, AccessParams):
            self._latitude = value
        else:
            self._latitude = AccessParams.from_alipay_dict(value)
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppTestTestCreateModel()
        if 'address' in d:
            o.address = d['address']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AuthenticationScene import AuthenticationScene


class AlipaySecurityRiskAuthenticationQueryModel(object):

    def __init__(self):
        self._authentication_scene = None
        self._biz_id = None
        self._biz_info = None
        self._token_id = None

    @property
    def authentication_scene(self):
        return self._authentication_scene

    @authentication_scene.setter
    def authentication_scene(self, value):
        if isinstance(value, AuthenticationScene):
            self._authentication_scene = value
        else:
            self._authentication_scene = AuthenticationScene.from_alipay_dict(value)
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def biz_info(self):
        return self._biz_info

    @biz_info.setter
    def biz_info(self, value):
        self._biz_info = value
    @property
    def token_id(self):
        return self._token_id

    @token_id.setter
    def token_id(self, value):
        self._token_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.authentication_scene:
            if hasattr(self.authentication_scene, 'to_alipay_dict'):
                params['authentication_scene'] = self.authentication_scene.to_alipay_dict()
            else:
                params['authentication_scene'] = self.authentication_scene
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.biz_info:
            if hasattr(self.biz_info, 'to_alipay_dict'):
                params['biz_info'] = self.biz_info.to_alipay_dict()
            else:
                params['biz_info'] = self.biz_info
        if self.token_id:
            if hasattr(self.token_id, 'to_alipay_dict'):
                params['token_id'] = self.token_id.to_alipay_dict()
            else:
                params['token_id'] = self.token_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityRiskAuthenticationQueryModel()
        if 'authentication_scene' in d:
            o.authentication_scene = d['authentication_scene']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'biz_info' in d:
            o.biz_info = d['biz_info']
        if 'token_id' in d:
            o.token_id = d['token_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FixExtData import FixExtData


class AlipayCommerceFixTaskCreateModel(object):

    def __init__(self):
        self._biz_type = None
        self._contact = None
        self._contact_phone = None
        self._description = None
        self._extra = None
        self._file_ids = None
        self._handler_id = None
        self._outer_id = None
        self._outer_system = None
        self._problem_id = None
        self._rule_scene = None
        self._source = None
        self._task_category = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def contact(self):
        return self._contact

    @contact.setter
    def contact(self, value):
        self._contact = value
    @property
    def contact_phone(self):
        return self._contact_phone

    @contact_phone.setter
    def contact_phone(self, value):
        self._contact_phone = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def extra(self):
        return self._extra

    @extra.setter
    def extra(self, value):
        if isinstance(value, list):
            self._extra = list()
            for i in value:
                if isinstance(i, FixExtData):
                    self._extra.append(i)
                else:
                    self._extra.append(FixExtData.from_alipay_dict(i))
    @property
    def file_ids(self):
        return self._file_ids

    @file_ids.setter
    def file_ids(self, value):
        self._file_ids = value
    @property
    def handler_id(self):
        return self._handler_id

    @handler_id.setter
    def handler_id(self, value):
        self._handler_id = value
    @property
    def outer_id(self):
        return self._outer_id

    @outer_id.setter
    def outer_id(self, value):
        self._outer_id = value
    @property
    def outer_system(self):
        return self._outer_system

    @outer_system.setter
    def outer_system(self, value):
        self._outer_system = value
    @property
    def problem_id(self):
        return self._problem_id

    @problem_id.setter
    def problem_id(self, value):
        self._problem_id = value
    @property
    def rule_scene(self):
        return self._rule_scene

    @rule_scene.setter
    def rule_scene(self, value):
        self._rule_scene = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def task_category(self):
        return self._task_category

    @task_category.setter
    def task_category(self, value):
        self._task_category = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.contact:
            if hasattr(self.contact, 'to_alipay_dict'):
                params['contact'] = self.contact.to_alipay_dict()
            else:
                params['contact'] = self.contact
        if self.contact_phone:
            if hasattr(self.contact_phone, 'to_alipay_dict'):
                params['contact_phone'] = self.contact_phone.to_alipay_dict()
            else:
                params['contact_phone'] = self.contact_phone
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.extra:
            if isinstance(self.extra, list):
                for i in range(0, len(self.extra)):
                    element = self.extra[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.extra[i] = element.to_alipay_dict()
            if hasattr(self.extra, 'to_alipay_dict'):
                params['extra'] = self.extra.to_alipay_dict()
            else:
                params['extra'] = self.extra
        if self.file_ids:
            if hasattr(self.file_ids, 'to_alipay_dict'):
                params['file_ids'] = self.file_ids.to_alipay_dict()
            else:
                params['file_ids'] = self.file_ids
        if self.handler_id:
            if hasattr(self.handler_id, 'to_alipay_dict'):
                params['handler_id'] = self.handler_id.to_alipay_dict()
            else:
                params['handler_id'] = self.handler_id
        if self.outer_id:
            if hasattr(self.outer_id, 'to_alipay_dict'):
                params['outer_id'] = self.outer_id.to_alipay_dict()
            else:
                params['outer_id'] = self.outer_id
        if self.outer_system:
            if hasattr(self.outer_system, 'to_alipay_dict'):
                params['outer_system'] = self.outer_system.to_alipay_dict()
            else:
                params['outer_system'] = self.outer_system
        if self.problem_id:
            if hasattr(self.problem_id, 'to_alipay_dict'):
                params['problem_id'] = self.problem_id.to_alipay_dict()
            else:
                params['problem_id'] = self.problem_id
        if self.rule_scene:
            if hasattr(self.rule_scene, 'to_alipay_dict'):
                params['rule_scene'] = self.rule_scene.to_alipay_dict()
            else:
                params['rule_scene'] = self.rule_scene
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.task_category:
            if hasattr(self.task_category, 'to_alipay_dict'):
                params['task_category'] = self.task_category.to_alipay_dict()
            else:
                params['task_category'] = self.task_category
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceFixTaskCreateModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'contact' in d:
            o.contact = d['contact']
        if 'contact_phone' in d:
            o.contact_phone = d['contact_phone']
        if 'description' in d:
            o.description = d['description']
        if 'extra' in d:
            o.extra = d['extra']
        if 'file_ids' in d:
            o.file_ids = d['file_ids']
        if 'handler_id' in d:
            o.handler_id = d['handler_id']
        if 'outer_id' in d:
            o.outer_id = d['outer_id']
        if 'outer_system' in d:
            o.outer_system = d['outer_system']
        if 'problem_id' in d:
            o.problem_id = d['problem_id']
        if 'rule_scene' in d:
            o.rule_scene = d['rule_scene']
        if 'source' in d:
            o.source = d['source']
        if 'task_category' in d:
            o.task_category = d['task_category']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AgentChatInfo import AgentChatInfo
from alipay.aop.api.domain.AgentHotlineInfo import AgentHotlineInfo
from alipay.aop.api.domain.RoleId import RoleId


class AlipayIserviceCcmAgentGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCcmAgentGetResponse, self).__init__()
        self._answering_mode = None
        self._avatar = None
        self._ccs_instance_ids = None
        self._chat_config = None
        self._create_time = None
        self._creator_id = None
        self._dingtalk_user_id = None
        self._email = None
        self._external_id = None
        self._hotline_config = None
        self._id = None
        self._job_number = None
        self._last_login_time = None
        self._mobile = None
        self._nick_name = None
        self._profile = None
        self._real_name = None
        self._role_ids = None
        self._status = None
        self._type = None
        self._update_time = None
        self._updater_id = None

    @property
    def answering_mode(self):
        return self._answering_mode

    @answering_mode.setter
    def answering_mode(self, value):
        self._answering_mode = value
    @property
    def avatar(self):
        return self._avatar

    @avatar.setter
    def avatar(self, value):
        self._avatar = value
    @property
    def ccs_instance_ids(self):
        return self._ccs_instance_ids

    @ccs_instance_ids.setter
    def ccs_instance_ids(self, value):
        if isinstance(value, list):
            self._ccs_instance_ids = list()
            for i in value:
                self._ccs_instance_ids.append(i)
    @property
    def chat_config(self):
        return self._chat_config

    @chat_config.setter
    def chat_config(self, value):
        if isinstance(value, list):
            self._chat_config = list()
            for i in value:
                if isinstance(i, AgentChatInfo):
                    self._chat_config.append(i)
                else:
                    self._chat_config.append(AgentChatInfo.from_alipay_dict(i))
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def dingtalk_user_id(self):
        return self._dingtalk_user_id

    @dingtalk_user_id.setter
    def dingtalk_user_id(self, value):
        self._dingtalk_user_id = value
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def hotline_config(self):
        return self._hotline_config

    @hotline_config.setter
    def hotline_config(self, value):
        if isinstance(value, list):
            self._hotline_config = list()
            for i in value:
                if isinstance(i, AgentHotlineInfo):
                    self._hotline_config.append(i)
                else:
                    self._hotline_config.append(AgentHotlineInfo.from_alipay_dict(i))
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def job_number(self):
        return self._job_number

    @job_number.setter
    def job_number(self, value):
        self._job_number = value
    @property
    def last_login_time(self):
        return self._last_login_time

    @last_login_time.setter
    def last_login_time(self, value):
        self._last_login_time = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def nick_name(self):
        return self._nick_name

    @nick_name.setter
    def nick_name(self, value):
        self._nick_name = value
    @property
    def profile(self):
        return self._profile

    @profile.setter
    def profile(self, value):
        self._profile = value
    @property
    def real_name(self):
        return self._real_name

    @real_name.setter
    def real_name(self, value):
        self._real_name = value
    @property
    def role_ids(self):
        return self._role_ids

    @role_ids.setter
    def role_ids(self, value):
        if isinstance(value, list):
            self._role_ids = list()
            for i in value:
                if isinstance(i, RoleId):
                    self._role_ids.append(i)
                else:
                    self._role_ids.append(RoleId.from_alipay_dict(i))
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def update_time(self):
        return self._update_time

    @update_time.setter
    def update_time(self, value):
        self._update_time = value
    @property
    def updater_id(self):
        return self._updater_id

    @updater_id.setter
    def updater_id(self, value):
        self._updater_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCcmAgentGetResponse, self).parse_response_content(response_content)
        if 'answering_mode' in response:
            self.answering_mode = response['answering_mode']
        if 'avatar' in response:
            self.avatar = response['avatar']
        if 'ccs_instance_ids' in response:
            self.ccs_instance_ids = response['ccs_instance_ids']
        if 'chat_config' in response:
            self.chat_config = response['chat_config']
        if 'create_time' in response:
            self.create_time = response['create_time']
        if 'creator_id' in response:
            self.creator_id = response['creator_id']
        if 'dingtalk_user_id' in response:
            self.dingtalk_user_id = response['dingtalk_user_id']
        if 'email' in response:
            self.email = response['email']
        if 'external_id' in response:
            self.external_id = response['external_id']
        if 'hotline_config' in response:
            self.hotline_config = response['hotline_config']
        if 'id' in response:
            self.id = response['id']
        if 'job_number' in response:
            self.job_number = response['job_number']
        if 'last_login_time' in response:
            self.last_login_time = response['last_login_time']
        if 'mobile' in response:
            self.mobile = response['mobile']
        if 'nick_name' in response:
            self.nick_name = response['nick_name']
        if 'profile' in response:
            self.profile = response['profile']
        if 'real_name' in response:
            self.real_name = response['real_name']
        if 'role_ids' in response:
            self.role_ids = response['role_ids']
        if 'status' in response:
            self.status = response['status']
        if 'type' in response:
            self.type = response['type']
        if 'update_time' in response:
            self.update_time = response['update_time']
        if 'updater_id' in response:
            self.updater_id = response['updater_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasTaxNeworderStatusSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTaxNeworderStatusSyncResponse, self).__init__()
        self._doc_id = None
        self._tax_order_no = None

    @property
    def doc_id(self):
        return self._doc_id

    @doc_id.setter
    def doc_id(self, value):
        self._doc_id = value
    @property
    def tax_order_no(self):
        return self._tax_order_no

    @tax_order_no.setter
    def tax_order_no(self, value):
        self._tax_order_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTaxNeworderStatusSyncResponse, self).parse_response_content(response_content)
        if 'doc_id' in response:
            self.doc_id = response['doc_id']
        if 'tax_order_no' in response:
            self.tax_order_no = response['tax_order_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OrderExt import OrderExt
from alipay.aop.api.domain.StoreOrderGood import StoreOrderGood


class AntMerchantOrderStoreQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantOrderStoreQueryResponse, self).__init__()
        self._buyer_id = None
        self._contact_phone = None
        self._ext = None
        self._goods_info_list = None
        self._memo = None
        self._order_id = None
        self._out_biz_no = None
        self._seller_id = None
        self._user_name = None

    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def contact_phone(self):
        return self._contact_phone

    @contact_phone.setter
    def contact_phone(self, value):
        self._contact_phone = value
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        if isinstance(value, list):
            self._ext = list()
            for i in value:
                if isinstance(i, OrderExt):
                    self._ext.append(i)
                else:
                    self._ext.append(OrderExt.from_alipay_dict(i))
    @property
    def goods_info_list(self):
        return self._goods_info_list

    @goods_info_list.setter
    def goods_info_list(self, value):
        if isinstance(value, list):
            self._goods_info_list = list()
            for i in value:
                if isinstance(i, StoreOrderGood):
                    self._goods_info_list.append(i)
                else:
                    self._goods_info_list.append(StoreOrderGood.from_alipay_dict(i))
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantOrderStoreQueryResponse, self).parse_response_content(response_content)
        if 'buyer_id' in response:
            self.buyer_id = response['buyer_id']
        if 'contact_phone' in response:
            self.contact_phone = response['contact_phone']
        if 'ext' in response:
            self.ext = response['ext']
        if 'goods_info_list' in response:
            self.goods_info_list = response['goods_info_list']
        if 'memo' in response:
            self.memo = response['memo']
        if 'order_id' in response:
            self.order_id = response['order_id']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'seller_id' in response:
            self.seller_id = response['seller_id']
        if 'user_name' in response:
            self.user_name = response['user_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GoodsDetail import GoodsDetail
from alipay.aop.api.domain.RefundGoodsDetail import RefundGoodsDetail
from alipay.aop.api.domain.OpenApiRoyaltyDetailInfoPojo import OpenApiRoyaltyDetailInfoPojo


class AlipayTradeRefundModel(object):

    def __init__(self):
        self._goods_detail = None
        self._operator_id = None
        self._org_pid = None
        self._out_request_no = None
        self._out_trade_no = None
        self._query_options = None
        self._refund_amount = None
        self._refund_currency = None
        self._refund_goods_detail = None
        self._refund_reason = None
        self._refund_royalty_parameters = None
        self._store_id = None
        self._terminal_id = None
        self._trade_no = None

    @property
    def goods_detail(self):
        return self._goods_detail

    @goods_detail.setter
    def goods_detail(self, value):
        if isinstance(value, list):
            self._goods_detail = list()
            for i in value:
                if isinstance(i, GoodsDetail):
                    self._goods_detail.append(i)
                else:
                    self._goods_detail.append(GoodsDetail.from_alipay_dict(i))
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def org_pid(self):
        return self._org_pid

    @org_pid.setter
    def org_pid(self, value):
        self._org_pid = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def query_options(self):
        return self._query_options

    @query_options.setter
    def query_options(self, value):
        if isinstance(value, list):
            self._query_options = list()
            for i in value:
                self._query_options.append(i)
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_currency(self):
        return self._refund_currency

    @refund_currency.setter
    def refund_currency(self, value):
        self._refund_currency = value
    @property
    def refund_goods_detail(self):
        return self._refund_goods_detail

    @refund_goods_detail.setter
    def refund_goods_detail(self, value):
        if isinstance(value, list):
            self._refund_goods_detail = list()
            for i in value:
                if isinstance(i, RefundGoodsDetail):
                    self._refund_goods_detail.append(i)
                else:
                    self._refund_goods_detail.append(RefundGoodsDetail.from_alipay_dict(i))
    @property
    def refund_reason(self):
        return self._refund_reason

    @refund_reason.setter
    def refund_reason(self, value):
        self._refund_reason = value
    @property
    def refund_royalty_parameters(self):
        return self._refund_royalty_parameters

    @refund_royalty_parameters.setter
    def refund_royalty_parameters(self, value):
        if isinstance(value, list):
            self._refund_royalty_parameters = list()
            for i in value:
                if isinstance(i, OpenApiRoyaltyDetailInfoPojo):
                    self._refund_royalty_parameters.append(i)
                else:
                    self._refund_royalty_parameters.append(OpenApiRoyaltyDetailInfoPojo.from_alipay_dict(i))
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value
    @property
    def terminal_id(self):
        return self._terminal_id

    @terminal_id.setter
    def terminal_id(self, value):
        self._terminal_id = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_detail:
            if isinstance(self.goods_detail, list):
                for i in range(0, len(self.goods_detail)):
                    element = self.goods_detail[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_detail[i] = element.to_alipay_dict()
            if hasattr(self.goods_detail, 'to_alipay_dict'):
                params['goods_detail'] = self.goods_detail.to_alipay_dict()
            else:
                params['goods_detail'] = self.goods_detail
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.org_pid:
            if hasattr(self.org_pid, 'to_alipay_dict'):
                params['org_pid'] = self.org_pid.to_alipay_dict()
            else:
                params['org_pid'] = self.org_pid
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.query_options:
            if isinstance(self.query_options, list):
                for i in range(0, len(self.query_options)):
                    element = self.query_options[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.query_options[i] = element.to_alipay_dict()
            if hasattr(self.query_options, 'to_alipay_dict'):
                params['query_options'] = self.query_options.to_alipay_dict()
            else:
                params['query_options'] = self.query_options
        if self.refund_amount:
            if hasattr(self.refund_amount, 'to_alipay_dict'):
                params['refund_amount'] = self.refund_amount.to_alipay_dict()
            else:
                params['refund_amount'] = self.refund_amount
        if self.refund_currency:
            if hasattr(self.refund_currency, 'to_alipay_dict'):
                params['refund_currency'] = self.refund_currency.to_alipay_dict()
            else:
                params['refund_currency'] = self.refund_currency
        if self.refund_goods_detail:
            if isinstance(self.refund_goods_detail, list):
                for i in range(0, len(self.refund_goods_detail)):
                    element = self.refund_goods_detail[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.refund_goods_detail[i] = element.to_alipay_dict()
            if hasattr(self.refund_goods_detail, 'to_alipay_dict'):
                params['refund_goods_detail'] = self.refund_goods_detail.to_alipay_dict()
            else:
                params['refund_goods_detail'] = self.refund_goods_detail
        if self.refund_reason:
            if hasattr(self.refund_reason, 'to_alipay_dict'):
                params['refund_reason'] = self.refund_reason.to_alipay_dict()
            else:
                params['refund_reason'] = self.refund_reason
        if self.refund_royalty_parameters:
            if isinstance(self.refund_royalty_parameters, list):
                for i in range(0, len(self.refund_royalty_parameters)):
                    element = self.refund_royalty_parameters[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.refund_royalty_parameters[i] = element.to_alipay_dict()
            if hasattr(self.refund_royalty_parameters, 'to_alipay_dict'):
                params['refund_royalty_parameters'] = self.refund_royalty_parameters.to_alipay_dict()
            else:
                params['refund_royalty_parameters'] = self.refund_royalty_parameters
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        if self.terminal_id:
            if hasattr(self.terminal_id, 'to_alipay_dict'):
                params['terminal_id'] = self.terminal_id.to_alipay_dict()
            else:
                params['terminal_id'] = self.terminal_id
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeRefundModel()
        if 'goods_detail' in d:
            o.goods_detail = d['goods_detail']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'org_pid' in d:
            o.org_pid = d['org_pid']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'query_options' in d:
            o.query_options = d['query_options']
        if 'refund_amount' in d:
            o.refund_amount = d['refund_amount']
        if 'refund_currency' in d:
            o.refund_currency = d['refund_currency']
        if 'refund_goods_detail' in d:
            o.refund_goods_detail = d['refund_goods_detail']
        if 'refund_reason' in d:
            o.refund_reason = d['refund_reason']
        if 'refund_royalty_parameters' in d:
            o.refund_royalty_parameters = d['refund_royalty_parameters']
        if 'store_id' in d:
            o.store_id = d['store_id']
        if 'terminal_id' in d:
            o.terminal_id = d['terminal_id']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.McaStoreLoanableDetail import McaStoreLoanableDetail


class MybankCreditSupplychainWfBillproductableamtQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSupplychainWfBillproductableamtQueryResponse, self).__init__()
        self._storeloanablelist = None

    @property
    def storeloanablelist(self):
        return self._storeloanablelist

    @storeloanablelist.setter
    def storeloanablelist(self, value):
        if isinstance(value, list):
            self._storeloanablelist = list()
            for i in value:
                if isinstance(i, McaStoreLoanableDetail):
                    self._storeloanablelist.append(i)
                else:
                    self._storeloanablelist.append(McaStoreLoanableDetail.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(MybankCreditSupplychainWfBillproductableamtQueryResponse, self).parse_response_content(response_content)
        if 'storeloanablelist' in response:
            self.storeloanablelist = response['storeloanablelist']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserCertifyIdentifyVerifyModel(object):

    def __init__(self):
        self._biz_code = None
        self._havana_id = None
        self._logon_id = None
        self._user_id = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def havana_id(self):
        return self._havana_id

    @havana_id.setter
    def havana_id(self, value):
        self._havana_id = value
    @property
    def logon_id(self):
        return self._logon_id

    @logon_id.setter
    def logon_id(self, value):
        self._logon_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.havana_id:
            if hasattr(self.havana_id, 'to_alipay_dict'):
                params['havana_id'] = self.havana_id.to_alipay_dict()
            else:
                params['havana_id'] = self.havana_id
        if self.logon_id:
            if hasattr(self.logon_id, 'to_alipay_dict'):
                params['logon_id'] = self.logon_id.to_alipay_dict()
            else:
                params['logon_id'] = self.logon_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserCertifyIdentifyVerifyModel()
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'havana_id' in d:
            o.havana_id = d['havana_id']
        if 'logon_id' in d:
            o.logon_id = d['logon_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenPublicShortlinkCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicShortlinkCreateResponse, self).__init__()
        self._shortlink = None

    @property
    def shortlink(self):
        return self._shortlink

    @shortlink.setter
    def shortlink(self, value):
        self._shortlink = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicShortlinkCreateResponse, self).parse_response_content(response_content)
        if 'shortlink' in response:
            self.shortlink = response['shortlink']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.NetFlowOfferInfo import NetFlowOfferInfo


class NetFlowDeviceOfferInfoResponse(object):

    def __init__(self):
        self._card_status = None
        self._expire_time = None
        self._net_flow_offer_info_list = None
        self._offer_amount = None
        self._offer_url = None

    @property
    def card_status(self):
        return self._card_status

    @card_status.setter
    def card_status(self, value):
        self._card_status = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def net_flow_offer_info_list(self):
        return self._net_flow_offer_info_list

    @net_flow_offer_info_list.setter
    def net_flow_offer_info_list(self, value):
        if isinstance(value, NetFlowOfferInfo):
            self._net_flow_offer_info_list = value
        else:
            self._net_flow_offer_info_list = NetFlowOfferInfo.from_alipay_dict(value)
    @property
    def offer_amount(self):
        return self._offer_amount

    @offer_amount.setter
    def offer_amount(self, value):
        self._offer_amount = value
    @property
    def offer_url(self):
        return self._offer_url

    @offer_url.setter
    def offer_url(self, value):
        self._offer_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_status:
            if hasattr(self.card_status, 'to_alipay_dict'):
                params['card_status'] = self.card_status.to_alipay_dict()
            else:
                params['card_status'] = self.card_status
        if self.expire_time:
            if hasattr(self.expire_time, 'to_alipay_dict'):
                params['expire_time'] = self.expire_time.to_alipay_dict()
            else:
                params['expire_time'] = self.expire_time
        if self.net_flow_offer_info_list:
            if hasattr(self.net_flow_offer_info_list, 'to_alipay_dict'):
                params['net_flow_offer_info_list'] = self.net_flow_offer_info_list.to_alipay_dict()
            else:
                params['net_flow_offer_info_list'] = self.net_flow_offer_info_list
        if self.offer_amount:
            if hasattr(self.offer_amount, 'to_alipay_dict'):
                params['offer_amount'] = self.offer_amount.to_alipay_dict()
            else:
                params['offer_amount'] = self.offer_amount
        if self.offer_url:
            if hasattr(self.offer_url, 'to_alipay_dict'):
                params['offer_url'] = self.offer_url.to_alipay_dict()
            else:
                params['offer_url'] = self.offer_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NetFlowDeviceOfferInfoResponse()
        if 'card_status' in d:
            o.card_status = d['card_status']
        if 'expire_time' in d:
            o.expire_time = d['expire_time']
        if 'net_flow_offer_info_list' in d:
            o.net_flow_offer_info_list = d['net_flow_offer_info_list']
        if 'offer_amount' in d:
            o.offer_amount = d['offer_amount']
        if 'offer_url' in d:
            o.offer_url = d['offer_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserPartnerPrivilegeauthbaseSyncModel(object):

    def __init__(self):
        self._biz_time = None
        self._current_count = None
        self._grade = None
        self._max_count = None
        self._out_biz_no = None
        self._privilege_id = None
        self._status = None
        self._title = None
        self._trans_quantum = None
        self._user_id = None

    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def current_count(self):
        return self._current_count

    @current_count.setter
    def current_count(self, value):
        self._current_count = value
    @property
    def grade(self):
        return self._grade

    @grade.setter
    def grade(self, value):
        self._grade = value
    @property
    def max_count(self):
        return self._max_count

    @max_count.setter
    def max_count(self, value):
        self._max_count = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def privilege_id(self):
        return self._privilege_id

    @privilege_id.setter
    def privilege_id(self, value):
        self._privilege_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def trans_quantum(self):
        return self._trans_quantum

    @trans_quantum.setter
    def trans_quantum(self, value):
        self._trans_quantum = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.current_count:
            if hasattr(self.current_count, 'to_alipay_dict'):
                params['current_count'] = self.current_count.to_alipay_dict()
            else:
                params['current_count'] = self.current_count
        if self.grade:
            if hasattr(self.grade, 'to_alipay_dict'):
                params['grade'] = self.grade.to_alipay_dict()
            else:
                params['grade'] = self.grade
        if self.max_count:
            if hasattr(self.max_count, 'to_alipay_dict'):
                params['max_count'] = self.max_count.to_alipay_dict()
            else:
                params['max_count'] = self.max_count
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.privilege_id:
            if hasattr(self.privilege_id, 'to_alipay_dict'):
                params['privilege_id'] = self.privilege_id.to_alipay_dict()
            else:
                params['privilege_id'] = self.privilege_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.trans_quantum:
            if hasattr(self.trans_quantum, 'to_alipay_dict'):
                params['trans_quantum'] = self.trans_quantum.to_alipay_dict()
            else:
                params['trans_quantum'] = self.trans_quantum
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserPartnerPrivilegeauthbaseSyncModel()
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'current_count' in d:
            o.current_count = d['current_count']
        if 'grade' in d:
            o.grade = d['grade']
        if 'max_count' in d:
            o.max_count = d['max_count']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'privilege_id' in d:
            o.privilege_id = d['privilege_id']
        if 'status' in d:
            o.status = d['status']
        if 'title' in d:
            o.title = d['title']
        if 'trans_quantum' in d:
            o.trans_quantum = d['trans_quantum']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IndustryQualificationInfoKt(object):

    def __init__(self):
        self._industry_qualification_image = None
        self._industry_qualification_type = None

    @property
    def industry_qualification_image(self):
        return self._industry_qualification_image

    @industry_qualification_image.setter
    def industry_qualification_image(self, value):
        self._industry_qualification_image = value
    @property
    def industry_qualification_type(self):
        return self._industry_qualification_type

    @industry_qualification_type.setter
    def industry_qualification_type(self, value):
        self._industry_qualification_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.industry_qualification_image:
            if hasattr(self.industry_qualification_image, 'to_alipay_dict'):
                params['industry_qualification_image'] = self.industry_qualification_image.to_alipay_dict()
            else:
                params['industry_qualification_image'] = self.industry_qualification_image
        if self.industry_qualification_type:
            if hasattr(self.industry_qualification_type, 'to_alipay_dict'):
                params['industry_qualification_type'] = self.industry_qualification_type.to_alipay_dict()
            else:
                params['industry_qualification_type'] = self.industry_qualification_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IndustryQualificationInfoKt()
        if 'industry_qualification_image' in d:
            o.industry_qualification_image = d['industry_qualification_image']
        if 'industry_qualification_type' in d:
            o.industry_qualification_type = d['industry_qualification_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntfortuneMarketingEquitycodeDiscryptGetResponse(AlipayResponse):

    def __init__(self):
        super(AntfortuneMarketingEquitycodeDiscryptGetResponse, self).__init__()
        self._equity_code = None
        self._should_retry = None

    @property
    def equity_code(self):
        return self._equity_code

    @equity_code.setter
    def equity_code(self, value):
        self._equity_code = value
    @property
    def should_retry(self):
        return self._should_retry

    @should_retry.setter
    def should_retry(self, value):
        self._should_retry = value

    def parse_response_content(self, response_content):
        response = super(AntfortuneMarketingEquitycodeDiscryptGetResponse, self).parse_response_content(response_content)
        if 'equity_code' in response:
            self.equity_code = response['equity_code']
        if 'should_retry' in response:
            self.should_retry = response['should_retry']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class SsdataDataserviceRiskAntifraudlistQueryResponse(AlipayResponse):

    def __init__(self):
        super(SsdataDataserviceRiskAntifraudlistQueryResponse, self).__init__()
        self._biz_no = None
        self._hit = None
        self._risk_code = None
        self._unique_id = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def hit(self):
        return self._hit

    @hit.setter
    def hit(self, value):
        self._hit = value
    @property
    def risk_code(self):
        return self._risk_code

    @risk_code.setter
    def risk_code(self, value):
        self._risk_code = value
    @property
    def unique_id(self):
        return self._unique_id

    @unique_id.setter
    def unique_id(self, value):
        self._unique_id = value

    def parse_response_content(self, response_content):
        response = super(SsdataDataserviceRiskAntifraudlistQueryResponse, self).parse_response_content(response_content)
        if 'biz_no' in response:
            self.biz_no = response['biz_no']
        if 'hit' in response:
            self.hit = response['hit']
        if 'risk_code' in response:
            self.risk_code = response['risk_code']
        if 'unique_id' in response:
            self.unique_id = response['unique_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppYoukuvideoAuditcallbackSendModel(object):

    def __init__(self):
        self._action = None
        self._old_action = None
        self._source = None
        self._vid = None

    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def old_action(self):
        return self._old_action

    @old_action.setter
    def old_action(self, value):
        self._old_action = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def vid(self):
        return self._vid

    @vid.setter
    def vid(self, value):
        self._vid = value


    def to_alipay_dict(self):
        params = dict()
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.old_action:
            if hasattr(self.old_action, 'to_alipay_dict'):
                params['old_action'] = self.old_action.to_alipay_dict()
            else:
                params['old_action'] = self.old_action
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.vid:
            if hasattr(self.vid, 'to_alipay_dict'):
                params['vid'] = self.vid.to_alipay_dict()
            else:
                params['vid'] = self.vid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppYoukuvideoAuditcallbackSendModel()
        if 'action' in d:
            o.action = d['action']
        if 'old_action' in d:
            o.old_action = d['old_action']
        if 'source' in d:
            o.source = d['source']
        if 'vid' in d:
            o.vid = d['vid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SystemParam import SystemParam


class AnttechBlockchainDefinFinanceOrderSubmitModel(object):

    def __init__(self):
        self._encoded_biz_param = None
        self._sys_param = None

    @property
    def encoded_biz_param(self):
        return self._encoded_biz_param

    @encoded_biz_param.setter
    def encoded_biz_param(self, value):
        self._encoded_biz_param = value
    @property
    def sys_param(self):
        return self._sys_param

    @sys_param.setter
    def sys_param(self, value):
        if isinstance(value, SystemParam):
            self._sys_param = value
        else:
            self._sys_param = SystemParam.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.encoded_biz_param:
            if hasattr(self.encoded_biz_param, 'to_alipay_dict'):
                params['encoded_biz_param'] = self.encoded_biz_param.to_alipay_dict()
            else:
                params['encoded_biz_param'] = self.encoded_biz_param
        if self.sys_param:
            if hasattr(self.sys_param, 'to_alipay_dict'):
                params['sys_param'] = self.sys_param.to_alipay_dict()
            else:
                params['sys_param'] = self.sys_param
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainDefinFinanceOrderSubmitModel()
        if 'encoded_biz_param' in d:
            o.encoded_biz_param = d['encoded_biz_param']
        if 'sys_param' in d:
            o.sys_param = d['sys_param']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RecommendBankInfo(object):

    def __init__(self):
        self._android_package_name = None
        self._android_schema = None
        self._bank_code = None
        self._bank_icon_url = None
        self._bank_name = None
        self._enable = None
        self._ios_schema = None
        self._memo = None

    @property
    def android_package_name(self):
        return self._android_package_name

    @android_package_name.setter
    def android_package_name(self, value):
        self._android_package_name = value
    @property
    def android_schema(self):
        return self._android_schema

    @android_schema.setter
    def android_schema(self, value):
        self._android_schema = value
    @property
    def bank_code(self):
        return self._bank_code

    @bank_code.setter
    def bank_code(self, value):
        self._bank_code = value
    @property
    def bank_icon_url(self):
        return self._bank_icon_url

    @bank_icon_url.setter
    def bank_icon_url(self, value):
        self._bank_icon_url = value
    @property
    def bank_name(self):
        return self._bank_name

    @bank_name.setter
    def bank_name(self, value):
        self._bank_name = value
    @property
    def enable(self):
        return self._enable

    @enable.setter
    def enable(self, value):
        self._enable = value
    @property
    def ios_schema(self):
        return self._ios_schema

    @ios_schema.setter
    def ios_schema(self, value):
        self._ios_schema = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value


    def to_alipay_dict(self):
        params = dict()
        if self.android_package_name:
            if hasattr(self.android_package_name, 'to_alipay_dict'):
                params['android_package_name'] = self.android_package_name.to_alipay_dict()
            else:
                params['android_package_name'] = self.android_package_name
        if self.android_schema:
            if hasattr(self.android_schema, 'to_alipay_dict'):
                params['android_schema'] = self.android_schema.to_alipay_dict()
            else:
                params['android_schema'] = self.android_schema
        if self.bank_code:
            if hasattr(self.bank_code, 'to_alipay_dict'):
                params['bank_code'] = self.bank_code.to_alipay_dict()
            else:
                params['bank_code'] = self.bank_code
        if self.bank_icon_url:
            if hasattr(self.bank_icon_url, 'to_alipay_dict'):
                params['bank_icon_url'] = self.bank_icon_url.to_alipay_dict()
            else:
                params['bank_icon_url'] = self.bank_icon_url
        if self.bank_name:
            if hasattr(self.bank_name, 'to_alipay_dict'):
                params['bank_name'] = self.bank_name.to_alipay_dict()
            else:
                params['bank_name'] = self.bank_name
        if self.enable:
            if hasattr(self.enable, 'to_alipay_dict'):
                params['enable'] = self.enable.to_alipay_dict()
            else:
                params['enable'] = self.enable
        if self.ios_schema:
            if hasattr(self.ios_schema, 'to_alipay_dict'):
                params['ios_schema'] = self.ios_schema.to_alipay_dict()
            else:
                params['ios_schema'] = self.ios_schema
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RecommendBankInfo()
        if 'android_package_name' in d:
            o.android_package_name = d['android_package_name']
        if 'android_schema' in d:
            o.android_schema = d['android_schema']
        if 'bank_code' in d:
            o.bank_code = d['bank_code']
        if 'bank_icon_url' in d:
            o.bank_icon_url = d['bank_icon_url']
        if 'bank_name' in d:
            o.bank_name = d['bank_name']
        if 'enable' in d:
            o.enable = d['enable']
        if 'ios_schema' in d:
            o.ios_schema = d['ios_schema']
        if 'memo' in d:
            o.memo = d['memo']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DiscountRandomModel(object):

    def __init__(self):
        self._max_amount = None
        self._min_amount = None
        self._probability = None

    @property
    def max_amount(self):
        return self._max_amount

    @max_amount.setter
    def max_amount(self, value):
        self._max_amount = value
    @property
    def min_amount(self):
        return self._min_amount

    @min_amount.setter
    def min_amount(self, value):
        self._min_amount = value
    @property
    def probability(self):
        return self._probability

    @probability.setter
    def probability(self, value):
        self._probability = value


    def to_alipay_dict(self):
        params = dict()
        if self.max_amount:
            if hasattr(self.max_amount, 'to_alipay_dict'):
                params['max_amount'] = self.max_amount.to_alipay_dict()
            else:
                params['max_amount'] = self.max_amount
        if self.min_amount:
            if hasattr(self.min_amount, 'to_alipay_dict'):
                params['min_amount'] = self.min_amount.to_alipay_dict()
            else:
                params['min_amount'] = self.min_amount
        if self.probability:
            if hasattr(self.probability, 'to_alipay_dict'):
                params['probability'] = self.probability.to_alipay_dict()
            else:
                params['probability'] = self.probability
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DiscountRandomModel()
        if 'max_amount' in d:
            o.max_amount = d['max_amount']
        if 'min_amount' in d:
            o.min_amount = d['min_amount']
        if 'probability' in d:
            o.probability = d['probability']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyVO import MultiCurrencyMoneyVO
from alipay.aop.api.domain.MultiCurrencyMoneyVO import MultiCurrencyMoneyVO
from alipay.aop.api.domain.MultiCurrencyMoneyVO import MultiCurrencyMoneyVO
from alipay.aop.api.domain.MultiCurrencyMoneyVO import MultiCurrencyMoneyVO
from alipay.aop.api.domain.MultiCurrencyMoneyVO import MultiCurrencyMoneyVO
from alipay.aop.api.domain.MultiCurrencyMoneyVO import MultiCurrencyMoneyVO


class BillAmtVo(object):

    def __init__(self):
        self._int_amt = None
        self._ovd_int_amt = None
        self._ovd_prin_amt = None
        self._pen_int_amt = None
        self._pen_prin_amt = None
        self._prin_amt = None

    @property
    def int_amt(self):
        return self._int_amt

    @int_amt.setter
    def int_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyVO):
            self._int_amt = value
        else:
            self._int_amt = MultiCurrencyMoneyVO.from_alipay_dict(value)
    @property
    def ovd_int_amt(self):
        return self._ovd_int_amt

    @ovd_int_amt.setter
    def ovd_int_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyVO):
            self._ovd_int_amt = value
        else:
            self._ovd_int_amt = MultiCurrencyMoneyVO.from_alipay_dict(value)
    @property
    def ovd_prin_amt(self):
        return self._ovd_prin_amt

    @ovd_prin_amt.setter
    def ovd_prin_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyVO):
            self._ovd_prin_amt = value
        else:
            self._ovd_prin_amt = MultiCurrencyMoneyVO.from_alipay_dict(value)
    @property
    def pen_int_amt(self):
        return self._pen_int_amt

    @pen_int_amt.setter
    def pen_int_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyVO):
            self._pen_int_amt = value
        else:
            self._pen_int_amt = MultiCurrencyMoneyVO.from_alipay_dict(value)
    @property
    def pen_prin_amt(self):
        return self._pen_prin_amt

    @pen_prin_amt.setter
    def pen_prin_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyVO):
            self._pen_prin_amt = value
        else:
            self._pen_prin_amt = MultiCurrencyMoneyVO.from_alipay_dict(value)
    @property
    def prin_amt(self):
        return self._prin_amt

    @prin_amt.setter
    def prin_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyVO):
            self._prin_amt = value
        else:
            self._prin_amt = MultiCurrencyMoneyVO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.int_amt:
            if hasattr(self.int_amt, 'to_alipay_dict'):
                params['int_amt'] = self.int_amt.to_alipay_dict()
            else:
                params['int_amt'] = self.int_amt
        if self.ovd_int_amt:
            if hasattr(self.ovd_int_amt, 'to_alipay_dict'):
                params['ovd_int_amt'] = self.ovd_int_amt.to_alipay_dict()
            else:
                params['ovd_int_amt'] = self.ovd_int_amt
        if self.ovd_prin_amt:
            if hasattr(self.ovd_prin_amt, 'to_alipay_dict'):
                params['ovd_prin_amt'] = self.ovd_prin_amt.to_alipay_dict()
            else:
                params['ovd_prin_amt'] = self.ovd_prin_amt
        if self.pen_int_amt:
            if hasattr(self.pen_int_amt, 'to_alipay_dict'):
                params['pen_int_amt'] = self.pen_int_amt.to_alipay_dict()
            else:
                params['pen_int_amt'] = self.pen_int_amt
        if self.pen_prin_amt:
            if hasattr(self.pen_prin_amt, 'to_alipay_dict'):
                params['pen_prin_amt'] = self.pen_prin_amt.to_alipay_dict()
            else:
                params['pen_prin_amt'] = self.pen_prin_amt
        if self.prin_amt:
            if hasattr(self.prin_amt, 'to_alipay_dict'):
                params['prin_amt'] = self.prin_amt.to_alipay_dict()
            else:
                params['prin_amt'] = self.prin_amt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BillAmtVo()
        if 'int_amt' in d:
            o.int_amt = d['int_amt']
        if 'ovd_int_amt' in d:
            o.ovd_int_amt = d['ovd_int_amt']
        if 'ovd_prin_amt' in d:
            o.ovd_prin_amt = d['ovd_prin_amt']
        if 'pen_int_amt' in d:
            o.pen_int_amt = d['pen_int_amt']
        if 'pen_prin_amt' in d:
            o.pen_prin_amt = d['pen_prin_amt']
        if 'prin_amt' in d:
            o.prin_amt = d['prin_amt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOverseasTravelRateQueryModel(object):

    def __init__(self):
        self._country_code = None
        self._currency = None
        self._extend_param = None
        self._latitude = None
        self._longitude = None
        self._user_id = None

    @property
    def country_code(self):
        return self._country_code

    @country_code.setter
    def country_code(self, value):
        self._country_code = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def extend_param(self):
        return self._extend_param

    @extend_param.setter
    def extend_param(self, value):
        self._extend_param = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.country_code:
            if hasattr(self.country_code, 'to_alipay_dict'):
                params['country_code'] = self.country_code.to_alipay_dict()
            else:
                params['country_code'] = self.country_code
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.extend_param:
            if hasattr(self.extend_param, 'to_alipay_dict'):
                params['extend_param'] = self.extend_param.to_alipay_dict()
            else:
                params['extend_param'] = self.extend_param
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasTravelRateQueryModel()
        if 'country_code' in d:
            o.country_code = d['country_code']
        if 'currency' in d:
            o.currency = d['currency']
        if 'extend_param' in d:
            o.extend_param = d['extend_param']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o


